/**
 * This code was obtained from
 * [`languages.json`](https://github.com/blakeembrey/language-map/blob/34783f1ad59d4e225e3e53a467e403540ea8e308/languages.json)
 * out of the npm package [`language-map`](https://www.npmjs.com/package/language-map) and modified
 * into a JS object so it doesn't need `with {type: 'json'}` (which isn't supported in our current
 * build target for ESM). TS types were also added.
 */
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Blake Embrey (hello@blakeembrey.com)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
export type LanguageEntry = {
    aceMode: string;
    languageId: number;
    tmScope: string;
    type: string;
    aliases?: string[];
    codemirrorMimeType?: string;
    codemirrorMode?: string;
    color?: string;
    extensions?: string[];
    filenames?: string[];
    fsName?: string;
    group?: string;
    interpreters?: string[];
    searchable?: boolean;
    wrap?: boolean;
};
export declare const languageMap: {
    readonly '1C Enterprise': {
        readonly type: "programming";
        readonly color: "#814CCC";
        readonly extensions: [".bsl", ".os"];
        readonly tmScope: "source.bsl";
        readonly aceMode: "text";
        readonly languageId: 0;
    };
    readonly '4D': {
        readonly type: "programming";
        readonly color: "#004289";
        readonly extensions: [".4dm"];
        readonly tmScope: "source.4dm";
        readonly aceMode: "text";
        readonly languageId: 577529595;
    };
    readonly ABAP: {
        readonly type: "programming";
        readonly color: "#E8274B";
        readonly extensions: [".abap"];
        readonly tmScope: "source.abap";
        readonly aceMode: "abap";
        readonly languageId: 1;
    };
    readonly 'ABAP CDS': {
        readonly type: "programming";
        readonly color: "#555e25";
        readonly extensions: [".asddls"];
        readonly tmScope: "source.abapcds";
        readonly languageId: 452681853;
        readonly aceMode: "text";
    };
    readonly ABNF: {
        readonly type: "data";
        readonly aceMode: "text";
        readonly extensions: [".abnf"];
        readonly tmScope: "source.abnf";
        readonly languageId: 429;
    };
    readonly 'AGS Script': {
        readonly type: "programming";
        readonly color: "#B9D9FF";
        readonly aliases: ["ags"];
        readonly extensions: [".asc", ".ash"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 2;
    };
    readonly AIDL: {
        readonly type: "programming";
        readonly color: "#34EB6B";
        readonly tmScope: "source.aidl";
        readonly extensions: [".aidl"];
        readonly aceMode: "text";
        readonly interpreters: ["aidl"];
        readonly languageId: 451700185;
    };
    readonly AL: {
        readonly type: "programming";
        readonly color: "#3AA2B5";
        readonly extensions: [".al"];
        readonly tmScope: "source.al";
        readonly aceMode: "text";
        readonly languageId: 658971832;
    };
    readonly AMPL: {
        readonly type: "programming";
        readonly color: "#E6EFBB";
        readonly extensions: [".ampl", ".mod"];
        readonly tmScope: "source.ampl";
        readonly aceMode: "text";
        readonly languageId: 3;
    };
    readonly ANTLR: {
        readonly type: "programming";
        readonly color: "#9DC3FF";
        readonly extensions: [".g4"];
        readonly tmScope: "source.antlr";
        readonly aceMode: "text";
        readonly languageId: 4;
    };
    readonly 'API Blueprint': {
        readonly type: "markup";
        readonly color: "#2ACCA8";
        readonly aceMode: "markdown";
        readonly extensions: [".apib"];
        readonly tmScope: "text.html.markdown.source.gfm.apib";
        readonly languageId: 5;
    };
    readonly APL: {
        readonly type: "programming";
        readonly color: "#5A8164";
        readonly extensions: [".apl", ".dyalog"];
        readonly interpreters: ["apl", "aplx", "dyalog"];
        readonly tmScope: "source.apl";
        readonly aceMode: "text";
        readonly codemirrorMode: "apl";
        readonly codemirrorMimeType: "text/apl";
        readonly languageId: 6;
    };
    readonly ASL: {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly extensions: [".asl", ".dsl"];
        readonly tmScope: "source.asl";
        readonly languageId: 124996147;
    };
    readonly 'ASN.1': {
        readonly type: "data";
        readonly extensions: [".asn", ".asn1"];
        readonly tmScope: "source.asn";
        readonly aceMode: "text";
        readonly codemirrorMode: "asn.1";
        readonly codemirrorMimeType: "text/x-ttcn-asn";
        readonly languageId: 7;
    };
    readonly 'ASP.NET': {
        readonly type: "programming";
        readonly tmScope: "text.html.asp";
        readonly color: "#9400ff";
        readonly aliases: ["aspx", "aspx-vb"];
        readonly extensions: [".asax", ".ascx", ".ashx", ".asmx", ".aspx", ".axd"];
        readonly aceMode: "text";
        readonly codemirrorMode: "htmlembedded";
        readonly codemirrorMimeType: "application/x-aspx";
        readonly languageId: 564186416;
    };
    readonly ATS: {
        readonly type: "programming";
        readonly color: "#1ac620";
        readonly aliases: ["ats2"];
        readonly extensions: [".dats", ".hats", ".sats"];
        readonly tmScope: "source.ats";
        readonly aceMode: "ocaml";
        readonly languageId: 9;
    };
    readonly ActionScript: {
        readonly type: "programming";
        readonly tmScope: "source.actionscript.3";
        readonly color: "#882B0F";
        readonly aliases: ["actionscript 3", "actionscript3", "as3"];
        readonly extensions: [".as"];
        readonly aceMode: "actionscript";
        readonly languageId: 10;
    };
    readonly Ada: {
        readonly type: "programming";
        readonly color: "#02f88c";
        readonly extensions: [".adb", ".ada", ".ads"];
        readonly aliases: ["ada95", "ada2005"];
        readonly tmScope: "source.ada";
        readonly aceMode: "ada";
        readonly languageId: 11;
    };
    readonly 'Adobe Font Metrics': {
        readonly type: "data";
        readonly color: "#fa0f00";
        readonly tmScope: "source.afm";
        readonly extensions: [".afm"];
        readonly aliases: ["acfm", "adobe composite font metrics", "adobe multiple font metrics", "amfm"];
        readonly aceMode: "text";
        readonly languageId: 147198098;
    };
    readonly Agda: {
        readonly type: "programming";
        readonly color: "#315665";
        readonly extensions: [".agda"];
        readonly tmScope: "source.agda";
        readonly aceMode: "text";
        readonly languageId: 12;
    };
    readonly Alloy: {
        readonly type: "programming";
        readonly color: "#64C800";
        readonly extensions: [".als"];
        readonly tmScope: "source.alloy";
        readonly aceMode: "text";
        readonly languageId: 13;
    };
    readonly 'Alpine Abuild': {
        readonly type: "programming";
        readonly color: "#0D597F";
        readonly group: "Shell";
        readonly aliases: ["abuild", "apkbuild"];
        readonly filenames: ["APKBUILD"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 14;
    };
    readonly 'Altium Designer': {
        readonly type: "data";
        readonly color: "#A89663";
        readonly aliases: ["altium"];
        readonly extensions: [".OutJob", ".PcbDoc", ".PrjPCB", ".SchDoc"];
        readonly tmScope: "source.ini";
        readonly aceMode: "ini";
        readonly languageId: 187772328;
    };
    readonly AngelScript: {
        readonly type: "programming";
        readonly color: "#C7D7DC";
        readonly extensions: [".as", ".angelscript"];
        readonly tmScope: "source.angelscript";
        readonly aceMode: "text";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 389477596;
    };
    readonly 'Ant Build System': {
        readonly type: "data";
        readonly color: "#A9157E";
        readonly tmScope: "text.xml.ant";
        readonly filenames: ["ant.xml", "build.xml"];
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "application/xml";
        readonly languageId: 15;
    };
    readonly ApacheConf: {
        readonly type: "data";
        readonly color: "#d12127";
        readonly aliases: ["aconf", "apache"];
        readonly extensions: [".apacheconf", ".vhost"];
        readonly filenames: [".htaccess", "apache2.conf", "httpd.conf"];
        readonly tmScope: "source.apache-config";
        readonly aceMode: "apache_conf";
        readonly languageId: 16;
    };
    readonly Apex: {
        readonly type: "programming";
        readonly color: "#1797c0";
        readonly extensions: [".cls"];
        readonly tmScope: "source.java";
        readonly aceMode: "java";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-java";
        readonly languageId: 17;
    };
    readonly 'Apollo Guidance Computer': {
        readonly type: "programming";
        readonly color: "#0B3D91";
        readonly group: "Assembly";
        readonly extensions: [".agc"];
        readonly tmScope: "source.agc";
        readonly aceMode: "assembly_x86";
        readonly languageId: 18;
    };
    readonly AppleScript: {
        readonly type: "programming";
        readonly aliases: ["osascript"];
        readonly extensions: [".applescript", ".scpt"];
        readonly interpreters: ["osascript"];
        readonly tmScope: "source.applescript";
        readonly aceMode: "applescript";
        readonly color: "#101F1F";
        readonly languageId: 19;
    };
    readonly Arc: {
        readonly type: "programming";
        readonly color: "#aa2afe";
        readonly extensions: [".arc"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 20;
    };
    readonly AsciiDoc: {
        readonly type: "prose";
        readonly color: "#73a0c5";
        readonly aceMode: "asciidoc";
        readonly wrap: true;
        readonly extensions: [".asciidoc", ".adoc", ".asc"];
        readonly tmScope: "text.html.asciidoc";
        readonly languageId: 22;
    };
    readonly AspectJ: {
        readonly type: "programming";
        readonly color: "#a957b0";
        readonly extensions: [".aj"];
        readonly tmScope: "source.aspectj";
        readonly aceMode: "text";
        readonly languageId: 23;
    };
    readonly Assembly: {
        readonly type: "programming";
        readonly color: "#6E4C13";
        readonly aliases: ["asm", "nasm"];
        readonly extensions: [".asm", ".a51", ".i", ".inc", ".nasm"];
        readonly tmScope: "source.assembly";
        readonly aceMode: "assembly_x86";
        readonly languageId: 24;
    };
    readonly Astro: {
        readonly type: "markup";
        readonly color: "#ff5a03";
        readonly extensions: [".astro"];
        readonly tmScope: "text.html.astro";
        readonly aceMode: "html";
        readonly codemirrorMode: "jsx";
        readonly codemirrorMimeType: "text/jsx";
        readonly languageId: 578209015;
    };
    readonly Asymptote: {
        readonly type: "programming";
        readonly color: "#ff0000";
        readonly extensions: [".asy"];
        readonly interpreters: ["asy"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-kotlin";
        readonly languageId: 591605007;
    };
    readonly Augeas: {
        readonly type: "programming";
        readonly color: "#9CC134";
        readonly extensions: [".aug"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 25;
    };
    readonly AutoHotkey: {
        readonly type: "programming";
        readonly color: "#6594b9";
        readonly aliases: ["ahk"];
        readonly extensions: [".ahk", ".ahkl"];
        readonly tmScope: "source.ahk";
        readonly aceMode: "autohotkey";
        readonly languageId: 26;
    };
    readonly AutoIt: {
        readonly type: "programming";
        readonly color: "#1C3552";
        readonly aliases: ["au3", "AutoIt3", "AutoItScript"];
        readonly extensions: [".au3"];
        readonly tmScope: "source.autoit";
        readonly aceMode: "autohotkey";
        readonly languageId: 27;
    };
    readonly 'Avro IDL': {
        readonly type: "data";
        readonly color: "#0040FF";
        readonly extensions: [".avdl"];
        readonly tmScope: "source.avro";
        readonly aceMode: "text";
        readonly languageId: 785497837;
    };
    readonly Awk: {
        readonly type: "programming";
        readonly color: "#c30e9b";
        readonly extensions: [".awk", ".auk", ".gawk", ".mawk", ".nawk"];
        readonly interpreters: ["awk", "gawk", "mawk", "nawk"];
        readonly tmScope: "source.awk";
        readonly aceMode: "text";
        readonly languageId: 28;
    };
    readonly BASIC: {
        readonly type: "programming";
        readonly extensions: [".bas"];
        readonly tmScope: "source.basic";
        readonly aceMode: "text";
        readonly color: "#ff0000";
        readonly languageId: 28923963;
    };
    readonly Ballerina: {
        readonly type: "programming";
        readonly extensions: [".bal"];
        readonly tmScope: "source.ballerina";
        readonly aceMode: "text";
        readonly color: "#FF5000";
        readonly languageId: 720859680;
    };
    readonly Batchfile: {
        readonly type: "programming";
        readonly aliases: ["bat", "batch", "dosbatch", "winbatch"];
        readonly extensions: [".bat", ".cmd"];
        readonly tmScope: "source.batchfile";
        readonly aceMode: "batchfile";
        readonly color: "#C1F12E";
        readonly languageId: 29;
    };
    readonly Beef: {
        readonly type: "programming";
        readonly color: "#a52f4e";
        readonly extensions: [".bf"];
        readonly tmScope: "source.cs";
        readonly aceMode: "csharp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csharp";
        readonly languageId: 545626333;
    };
    readonly Befunge: {
        readonly type: "programming";
        readonly extensions: [".befunge"];
        readonly tmScope: "source.befunge";
        readonly aceMode: "text";
        readonly languageId: 30;
    };
    readonly BibTeX: {
        readonly type: "markup";
        readonly color: "#778899";
        readonly group: "TeX";
        readonly extensions: [".bib", ".bibtex"];
        readonly tmScope: "text.bibtex";
        readonly aceMode: "tex";
        readonly codemirrorMode: "stex";
        readonly codemirrorMimeType: "text/x-stex";
        readonly languageId: 982188347;
    };
    readonly Bicep: {
        readonly type: "programming";
        readonly color: "#519aba";
        readonly extensions: [".bicep"];
        readonly tmScope: "source.bicep";
        readonly aceMode: "text";
        readonly languageId: 321200902;
    };
    readonly Bison: {
        readonly type: "programming";
        readonly color: "#6A463F";
        readonly group: "Yacc";
        readonly tmScope: "source.yacc";
        readonly extensions: [".bison"];
        readonly aceMode: "text";
        readonly languageId: 31;
    };
    readonly BitBake: {
        readonly type: "programming";
        readonly color: "#00bce4";
        readonly tmScope: "none";
        readonly extensions: [".bb"];
        readonly aceMode: "text";
        readonly languageId: 32;
    };
    readonly Blade: {
        readonly type: "markup";
        readonly color: "#f7523f";
        readonly extensions: [".blade", ".blade.php"];
        readonly tmScope: "text.html.php.blade";
        readonly aceMode: "text";
        readonly languageId: 33;
    };
    readonly BlitzBasic: {
        readonly type: "programming";
        readonly color: "#00FFAE";
        readonly aliases: ["b3d", "blitz3d", "blitzplus", "bplus"];
        readonly extensions: [".bb", ".decls"];
        readonly tmScope: "source.blitzmax";
        readonly aceMode: "text";
        readonly languageId: 34;
    };
    readonly BlitzMax: {
        readonly type: "programming";
        readonly color: "#cd6400";
        readonly extensions: [".bmx"];
        readonly aliases: ["bmax"];
        readonly tmScope: "source.blitzmax";
        readonly aceMode: "text";
        readonly languageId: 35;
    };
    readonly Bluespec: {
        readonly type: "programming";
        readonly color: "#12223c";
        readonly extensions: [".bsv"];
        readonly tmScope: "source.bsv";
        readonly aceMode: "verilog";
        readonly languageId: 36;
    };
    readonly Boo: {
        readonly type: "programming";
        readonly color: "#d4bec1";
        readonly extensions: [".boo"];
        readonly aceMode: "text";
        readonly tmScope: "source.boo";
        readonly languageId: 37;
    };
    readonly Boogie: {
        readonly type: "programming";
        readonly color: "#c80fa0";
        readonly extensions: [".bpl"];
        readonly interpreters: ["boogie"];
        readonly tmScope: "source.boogie";
        readonly aceMode: "text";
        readonly languageId: 955017407;
    };
    readonly Brainfuck: {
        readonly type: "programming";
        readonly color: "#2F2530";
        readonly extensions: [".b", ".bf"];
        readonly tmScope: "source.bf";
        readonly aceMode: "text";
        readonly codemirrorMode: "brainfuck";
        readonly codemirrorMimeType: "text/x-brainfuck";
        readonly languageId: 38;
    };
    readonly Brightscript: {
        readonly type: "programming";
        readonly color: "#662D91";
        readonly extensions: [".brs"];
        readonly tmScope: "source.brightscript";
        readonly aceMode: "text";
        readonly languageId: 39;
    };
    readonly Browserslist: {
        readonly type: "data";
        readonly color: "#ffd539";
        readonly filenames: [".browserslistrc", "browserslist"];
        readonly tmScope: "text.browserslist";
        readonly aceMode: "text";
        readonly languageId: 153503348;
    };
    readonly C: {
        readonly type: "programming";
        readonly color: "#555555";
        readonly extensions: [".c", ".cats", ".h", ".idc"];
        readonly interpreters: ["tcc"];
        readonly tmScope: "source.c";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 41;
    };
    readonly 'C#': {
        readonly type: "programming";
        readonly aceMode: "csharp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csharp";
        readonly tmScope: "source.cs";
        readonly color: "#178600";
        readonly aliases: ["csharp", "cake", "cakescript"];
        readonly extensions: [".cs", ".cake", ".csx", ".linq"];
        readonly languageId: 42;
    };
    readonly 'C++': {
        readonly type: "programming";
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly color: "#f34b7d";
        readonly aliases: ["cpp"];
        readonly extensions: [".cpp", ".c++", ".cc", ".cp", ".cxx", ".h", ".h++", ".hh", ".hpp", ".hxx", ".inc", ".inl", ".ino", ".ipp", ".re", ".tcc", ".tpp"];
        readonly languageId: 43;
    };
    readonly 'C-ObjDump': {
        readonly type: "data";
        readonly extensions: [".c-objdump"];
        readonly tmScope: "objdump.x86asm";
        readonly aceMode: "assembly_x86";
        readonly languageId: 44;
    };
    readonly 'C2hs Haskell': {
        readonly type: "programming";
        readonly group: "Haskell";
        readonly aliases: ["c2hs"];
        readonly extensions: [".chs"];
        readonly tmScope: "source.haskell";
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly languageId: 45;
    };
    readonly CIL: {
        readonly type: "data";
        readonly tmScope: "source.cil";
        readonly extensions: [".cil"];
        readonly aceMode: "text";
        readonly languageId: 29176339;
    };
    readonly CLIPS: {
        readonly type: "programming";
        readonly color: "#00A300";
        readonly extensions: [".clp"];
        readonly tmScope: "source.clips";
        readonly aceMode: "text";
        readonly languageId: 46;
    };
    readonly CMake: {
        readonly type: "programming";
        readonly color: "#DA3434";
        readonly extensions: [".cmake", ".cmake.in"];
        readonly filenames: ["CMakeLists.txt"];
        readonly tmScope: "source.cmake";
        readonly aceMode: "text";
        readonly codemirrorMode: "cmake";
        readonly codemirrorMimeType: "text/x-cmake";
        readonly languageId: 47;
    };
    readonly COBOL: {
        readonly type: "programming";
        readonly extensions: [".cob", ".cbl", ".ccp", ".cobol", ".cpy"];
        readonly tmScope: "source.cobol";
        readonly aceMode: "cobol";
        readonly codemirrorMode: "cobol";
        readonly codemirrorMimeType: "text/x-cobol";
        readonly languageId: 48;
    };
    readonly CODEOWNERS: {
        readonly type: "data";
        readonly filenames: ["CODEOWNERS"];
        readonly tmScope: "text.codeowners";
        readonly aceMode: "gitignore";
        readonly languageId: 321684729;
    };
    readonly COLLADA: {
        readonly type: "data";
        readonly color: "#F1A42B";
        readonly extensions: [".dae"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 49;
    };
    readonly CSON: {
        readonly type: "data";
        readonly color: "#244776";
        readonly tmScope: "source.coffee";
        readonly aceMode: "coffee";
        readonly codemirrorMode: "coffeescript";
        readonly codemirrorMimeType: "text/x-coffeescript";
        readonly extensions: [".cson"];
        readonly languageId: 424;
    };
    readonly CSS: {
        readonly type: "markup";
        readonly tmScope: "source.css";
        readonly aceMode: "css";
        readonly codemirrorMode: "css";
        readonly codemirrorMimeType: "text/css";
        readonly color: "#563d7c";
        readonly extensions: [".css"];
        readonly languageId: 50;
    };
    readonly CSV: {
        readonly type: "data";
        readonly color: "#237346";
        readonly aceMode: "text";
        readonly tmScope: "none";
        readonly extensions: [".csv"];
        readonly languageId: 51;
    };
    readonly CUE: {
        readonly type: "programming";
        readonly extensions: [".cue"];
        readonly tmScope: "source.cue";
        readonly aceMode: "text";
        readonly color: "#5886E1";
        readonly languageId: 356063509;
    };
    readonly CWeb: {
        readonly type: "programming";
        readonly color: "#00007a";
        readonly extensions: [".w"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 657332628;
    };
    readonly 'Cabal Config': {
        readonly type: "data";
        readonly color: "#483465";
        readonly aliases: ["Cabal"];
        readonly extensions: [".cabal"];
        readonly filenames: ["cabal.config", "cabal.project"];
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly tmScope: "source.cabal";
        readonly languageId: 677095381;
    };
    readonly "Cap'n Proto": {
        readonly type: "programming";
        readonly color: "#c42727";
        readonly tmScope: "source.capnp";
        readonly extensions: [".capnp"];
        readonly aceMode: "text";
        readonly languageId: 52;
    };
    readonly CartoCSS: {
        readonly type: "programming";
        readonly aliases: ["Carto"];
        readonly extensions: [".mss"];
        readonly aceMode: "text";
        readonly tmScope: "source.css.mss";
        readonly languageId: 53;
    };
    readonly Ceylon: {
        readonly type: "programming";
        readonly color: "#dfa535";
        readonly extensions: [".ceylon"];
        readonly tmScope: "source.ceylon";
        readonly aceMode: "text";
        readonly languageId: 54;
    };
    readonly Chapel: {
        readonly type: "programming";
        readonly color: "#8dc63f";
        readonly aliases: ["chpl"];
        readonly extensions: [".chpl"];
        readonly tmScope: "source.chapel";
        readonly aceMode: "text";
        readonly languageId: 55;
    };
    readonly Charity: {
        readonly type: "programming";
        readonly extensions: [".ch"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 56;
    };
    readonly ChucK: {
        readonly type: "programming";
        readonly color: "#3f8000";
        readonly extensions: [".ck"];
        readonly tmScope: "source.java";
        readonly aceMode: "java";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-java";
        readonly languageId: 57;
    };
    readonly Cirru: {
        readonly type: "programming";
        readonly color: "#ccccff";
        readonly tmScope: "source.cirru";
        readonly aceMode: "cirru";
        readonly extensions: [".cirru"];
        readonly languageId: 58;
    };
    readonly Clarion: {
        readonly type: "programming";
        readonly color: "#db901e";
        readonly aceMode: "text";
        readonly extensions: [".clw"];
        readonly tmScope: "source.clarion";
        readonly languageId: 59;
    };
    readonly 'Classic ASP': {
        readonly type: "programming";
        readonly color: "#6a40fd";
        readonly tmScope: "text.html.asp";
        readonly aliases: ["asp"];
        readonly extensions: [".asp"];
        readonly aceMode: "text";
        readonly languageId: 8;
    };
    readonly Clean: {
        readonly type: "programming";
        readonly color: "#3F85AF";
        readonly extensions: [".icl", ".dcl"];
        readonly tmScope: "source.clean";
        readonly aceMode: "text";
        readonly languageId: 60;
    };
    readonly Click: {
        readonly type: "programming";
        readonly color: "#E4E6F3";
        readonly extensions: [".click"];
        readonly tmScope: "source.click";
        readonly aceMode: "text";
        readonly languageId: 61;
    };
    readonly Clojure: {
        readonly type: "programming";
        readonly tmScope: "source.clojure";
        readonly aceMode: "clojure";
        readonly codemirrorMode: "clojure";
        readonly codemirrorMimeType: "text/x-clojure";
        readonly color: "#db5855";
        readonly extensions: [".clj", ".boot", ".cl2", ".cljc", ".cljs", ".cljs.hl", ".cljscm", ".cljx", ".hic"];
        readonly filenames: ["riemann.config"];
        readonly languageId: 62;
    };
    readonly 'Closure Templates': {
        readonly type: "markup";
        readonly color: "#0d948f";
        readonly aceMode: "soy_template";
        readonly codemirrorMode: "soy";
        readonly codemirrorMimeType: "text/x-soy";
        readonly aliases: ["soy"];
        readonly extensions: [".soy"];
        readonly tmScope: "text.html.soy";
        readonly languageId: 357046146;
    };
    readonly 'Cloud Firestore Security Rules': {
        readonly type: "data";
        readonly color: "#FFA000";
        readonly aceMode: "less";
        readonly codemirrorMode: "css";
        readonly codemirrorMimeType: "text/css";
        readonly tmScope: "source.firestore";
        readonly filenames: ["firestore.rules"];
        readonly languageId: 407996372;
    };
    readonly 'CoNLL-U': {
        readonly type: "data";
        readonly extensions: [".conllu", ".conll"];
        readonly tmScope: "text.conllu";
        readonly aceMode: "text";
        readonly aliases: ["CoNLL", "CoNLL-X"];
        readonly languageId: 421026389;
    };
    readonly CodeQL: {
        readonly type: "programming";
        readonly color: "#140f46";
        readonly extensions: [".ql", ".qll"];
        readonly tmScope: "source.ql";
        readonly aceMode: "text";
        readonly languageId: 424259634;
        readonly aliases: ["ql"];
    };
    readonly CoffeeScript: {
        readonly type: "programming";
        readonly tmScope: "source.coffee";
        readonly aceMode: "coffee";
        readonly codemirrorMode: "coffeescript";
        readonly codemirrorMimeType: "text/x-coffeescript";
        readonly color: "#244776";
        readonly aliases: ["coffee", "coffee-script"];
        readonly extensions: [".coffee", "._coffee", ".cake", ".cjsx", ".iced"];
        readonly filenames: ["Cakefile"];
        readonly interpreters: ["coffee"];
        readonly languageId: 63;
    };
    readonly ColdFusion: {
        readonly type: "programming";
        readonly aceMode: "coldfusion";
        readonly color: "#ed2cd6";
        readonly aliases: ["cfm", "cfml", "coldfusion html"];
        readonly extensions: [".cfm", ".cfml"];
        readonly tmScope: "text.html.cfm";
        readonly languageId: 64;
    };
    readonly 'ColdFusion CFC': {
        readonly type: "programming";
        readonly color: "#ed2cd6";
        readonly group: "ColdFusion";
        readonly aceMode: "coldfusion";
        readonly aliases: ["cfc"];
        readonly extensions: [".cfc"];
        readonly tmScope: "source.cfscript";
        readonly languageId: 65;
    };
    readonly 'Common Lisp': {
        readonly type: "programming";
        readonly tmScope: "source.lisp";
        readonly color: "#3fb68b";
        readonly aliases: ["lisp"];
        readonly extensions: [".lisp", ".asd", ".cl", ".l", ".lsp", ".ny", ".podsl", ".sexp"];
        readonly interpreters: ["lisp", "sbcl", "ccl", "clisp", "ecl"];
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 66;
    };
    readonly 'Common Workflow Language': {
        readonly aliases: ["cwl"];
        readonly type: "programming";
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly extensions: [".cwl"];
        readonly interpreters: ["cwl-runner"];
        readonly color: "#B5314C";
        readonly tmScope: "source.cwl";
        readonly languageId: 988547172;
    };
    readonly 'Component Pascal': {
        readonly type: "programming";
        readonly color: "#B0CE4E";
        readonly extensions: [".cp", ".cps"];
        readonly tmScope: "source.pascal";
        readonly aceMode: "pascal";
        readonly codemirrorMode: "pascal";
        readonly codemirrorMimeType: "text/x-pascal";
        readonly languageId: 67;
    };
    readonly Cool: {
        readonly type: "programming";
        readonly extensions: [".cl"];
        readonly tmScope: "source.cool";
        readonly aceMode: "text";
        readonly languageId: 68;
    };
    readonly Coq: {
        readonly type: "programming";
        readonly color: "#d0b68c";
        readonly extensions: [".coq", ".v"];
        readonly tmScope: "source.coq";
        readonly aceMode: "text";
        readonly languageId: 69;
    };
    readonly 'Cpp-ObjDump': {
        readonly type: "data";
        readonly extensions: [".cppobjdump", ".c++-objdump", ".c++objdump", ".cpp-objdump", ".cxx-objdump"];
        readonly tmScope: "objdump.x86asm";
        readonly aliases: ["c++-objdump"];
        readonly aceMode: "assembly_x86";
        readonly languageId: 70;
    };
    readonly Creole: {
        readonly type: "prose";
        readonly wrap: true;
        readonly extensions: [".creole"];
        readonly tmScope: "text.html.creole";
        readonly aceMode: "text";
        readonly languageId: 71;
    };
    readonly Crystal: {
        readonly type: "programming";
        readonly color: "#000100";
        readonly extensions: [".cr"];
        readonly aceMode: "ruby";
        readonly codemirrorMode: "crystal";
        readonly codemirrorMimeType: "text/x-crystal";
        readonly tmScope: "source.crystal";
        readonly interpreters: ["crystal"];
        readonly languageId: 72;
    };
    readonly Csound: {
        readonly type: "programming";
        readonly color: "#1a1a1a";
        readonly aliases: ["csound-orc"];
        readonly extensions: [".orc", ".udo"];
        readonly tmScope: "source.csound";
        readonly aceMode: "csound_orchestra";
        readonly languageId: 73;
    };
    readonly 'Csound Document': {
        readonly type: "programming";
        readonly color: "#1a1a1a";
        readonly aliases: ["csound-csd"];
        readonly extensions: [".csd"];
        readonly tmScope: "source.csound-document";
        readonly aceMode: "csound_document";
        readonly languageId: 74;
    };
    readonly 'Csound Score': {
        readonly type: "programming";
        readonly color: "#1a1a1a";
        readonly aliases: ["csound-sco"];
        readonly extensions: [".sco"];
        readonly tmScope: "source.csound-score";
        readonly aceMode: "csound_score";
        readonly languageId: 75;
    };
    readonly Cuda: {
        readonly type: "programming";
        readonly extensions: [".cu", ".cuh"];
        readonly tmScope: "source.cuda-c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly color: "#3A4E3A";
        readonly languageId: 77;
    };
    readonly 'Cue Sheet': {
        readonly type: "data";
        readonly extensions: [".cue"];
        readonly tmScope: "source.cuesheet";
        readonly aceMode: "text";
        readonly languageId: 942714150;
    };
    readonly Cycript: {
        readonly type: "programming";
        readonly extensions: [".cy"];
        readonly tmScope: "source.js";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "text/javascript";
        readonly languageId: 78;
    };
    readonly Cython: {
        readonly type: "programming";
        readonly color: "#fedf5b";
        readonly extensions: [".pyx", ".pxd", ".pxi"];
        readonly aliases: ["pyrex"];
        readonly tmScope: "source.cython";
        readonly aceMode: "text";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-cython";
        readonly languageId: 79;
    };
    readonly D: {
        readonly type: "programming";
        readonly color: "#ba595e";
        readonly aliases: ["Dlang"];
        readonly extensions: [".d", ".di"];
        readonly tmScope: "source.d";
        readonly aceMode: "d";
        readonly codemirrorMode: "d";
        readonly codemirrorMimeType: "text/x-d";
        readonly languageId: 80;
    };
    readonly 'D-ObjDump': {
        readonly type: "data";
        readonly extensions: [".d-objdump"];
        readonly tmScope: "objdump.x86asm";
        readonly aceMode: "assembly_x86";
        readonly languageId: 81;
    };
    readonly 'DIGITAL Command Language': {
        readonly type: "programming";
        readonly aliases: ["dcl"];
        readonly extensions: [".com"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 82;
    };
    readonly DM: {
        readonly type: "programming";
        readonly color: "#447265";
        readonly extensions: [".dm"];
        readonly aliases: ["byond"];
        readonly tmScope: "source.dm";
        readonly aceMode: "c_cpp";
        readonly languageId: 83;
    };
    readonly 'DNS Zone': {
        readonly type: "data";
        readonly extensions: [".zone", ".arpa"];
        readonly tmScope: "text.zone_file";
        readonly aceMode: "text";
        readonly languageId: 84;
    };
    readonly DTrace: {
        readonly type: "programming";
        readonly aliases: ["dtrace-script"];
        readonly extensions: [".d"];
        readonly interpreters: ["dtrace"];
        readonly tmScope: "source.c";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 85;
    };
    readonly Dafny: {
        readonly type: "programming";
        readonly color: "#FFEC25";
        readonly extensions: [".dfy"];
        readonly interpreters: ["dafny"];
        readonly tmScope: "text.dfy.dafny";
        readonly aceMode: "text";
        readonly languageId: 969323346;
    };
    readonly 'Darcs Patch': {
        readonly type: "data";
        readonly color: "#8eff23";
        readonly aliases: ["dpatch"];
        readonly extensions: [".darcspatch", ".dpatch"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 86;
    };
    readonly Dart: {
        readonly type: "programming";
        readonly color: "#00B4AB";
        readonly extensions: [".dart"];
        readonly interpreters: ["dart"];
        readonly tmScope: "source.dart";
        readonly aceMode: "dart";
        readonly codemirrorMode: "dart";
        readonly codemirrorMimeType: "application/dart";
        readonly languageId: 87;
    };
    readonly DataWeave: {
        readonly type: "programming";
        readonly color: "#003a52";
        readonly extensions: [".dwl"];
        readonly aceMode: "text";
        readonly tmScope: "source.data-weave";
        readonly languageId: 974514097;
    };
    readonly Dhall: {
        readonly type: "programming";
        readonly color: "#dfafff";
        readonly extensions: [".dhall"];
        readonly tmScope: "source.haskell";
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly languageId: 793969321;
    };
    readonly Diff: {
        readonly type: "data";
        readonly extensions: [".diff", ".patch"];
        readonly aliases: ["udiff"];
        readonly tmScope: "source.diff";
        readonly aceMode: "diff";
        readonly codemirrorMode: "diff";
        readonly codemirrorMimeType: "text/x-diff";
        readonly languageId: 88;
    };
    readonly 'DirectX 3D File': {
        readonly type: "data";
        readonly color: "#aace60";
        readonly extensions: [".x"];
        readonly aceMode: "text";
        readonly tmScope: "none";
        readonly languageId: 201049282;
    };
    readonly Dockerfile: {
        readonly type: "programming";
        readonly color: "#384d54";
        readonly tmScope: "source.dockerfile";
        readonly extensions: [".dockerfile"];
        readonly filenames: ["Dockerfile"];
        readonly aceMode: "dockerfile";
        readonly codemirrorMode: "dockerfile";
        readonly codemirrorMimeType: "text/x-dockerfile";
        readonly languageId: 89;
    };
    readonly Dogescript: {
        readonly type: "programming";
        readonly color: "#cca760";
        readonly extensions: [".djs"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 90;
    };
    readonly Dylan: {
        readonly type: "programming";
        readonly color: "#6c616e";
        readonly extensions: [".dylan", ".dyl", ".intr", ".lid"];
        readonly tmScope: "source.dylan";
        readonly aceMode: "text";
        readonly codemirrorMode: "dylan";
        readonly codemirrorMimeType: "text/x-dylan";
        readonly languageId: 91;
    };
    readonly E: {
        readonly type: "programming";
        readonly color: "#ccce35";
        readonly extensions: [".E"];
        readonly interpreters: ["rune"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 92;
    };
    readonly 'E-mail': {
        readonly type: "data";
        readonly aliases: ["email", "eml", "mail", "mbox"];
        readonly extensions: [".eml", ".mbox"];
        readonly tmScope: "text.eml.basic";
        readonly aceMode: "text";
        readonly codemirrorMode: "mbox";
        readonly codemirrorMimeType: "application/mbox";
        readonly languageId: 529653389;
    };
    readonly EBNF: {
        readonly type: "data";
        readonly extensions: [".ebnf"];
        readonly tmScope: "source.ebnf";
        readonly aceMode: "text";
        readonly codemirrorMode: "ebnf";
        readonly codemirrorMimeType: "text/x-ebnf";
        readonly languageId: 430;
    };
    readonly ECL: {
        readonly type: "programming";
        readonly color: "#8a1267";
        readonly extensions: [".ecl", ".eclxml"];
        readonly tmScope: "source.ecl";
        readonly aceMode: "text";
        readonly codemirrorMode: "ecl";
        readonly codemirrorMimeType: "text/x-ecl";
        readonly languageId: 93;
    };
    readonly ECLiPSe: {
        readonly type: "programming";
        readonly color: "#001d9d";
        readonly group: "prolog";
        readonly extensions: [".ecl"];
        readonly tmScope: "source.prolog.eclipse";
        readonly aceMode: "prolog";
        readonly languageId: 94;
    };
    readonly EJS: {
        readonly type: "markup";
        readonly color: "#a91e50";
        readonly extensions: [".ejs", ".ect", ".jst"];
        readonly tmScope: "text.html.js";
        readonly aceMode: "ejs";
        readonly languageId: 95;
    };
    readonly EQ: {
        readonly type: "programming";
        readonly color: "#a78649";
        readonly extensions: [".eq"];
        readonly tmScope: "source.cs";
        readonly aceMode: "csharp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csharp";
        readonly languageId: 96;
    };
    readonly Eagle: {
        readonly type: "data";
        readonly extensions: [".sch", ".brd"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 97;
    };
    readonly Easybuild: {
        readonly type: "data";
        readonly color: "#069406";
        readonly group: "Python";
        readonly aceMode: "python";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly tmScope: "source.python";
        readonly extensions: [".eb"];
        readonly languageId: 342840477;
    };
    readonly 'Ecere Projects': {
        readonly type: "data";
        readonly color: "#913960";
        readonly group: "JavaScript";
        readonly extensions: [".epj"];
        readonly tmScope: "source.json";
        readonly aceMode: "json";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly languageId: 98;
    };
    readonly EditorConfig: {
        readonly type: "data";
        readonly color: "#fff1f2";
        readonly group: "INI";
        readonly filenames: [".editorconfig"];
        readonly aliases: ["editor-config"];
        readonly aceMode: "ini";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly tmScope: "source.editorconfig";
        readonly languageId: 96139566;
    };
    readonly 'Edje Data Collection': {
        readonly type: "data";
        readonly extensions: [".edc"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 342840478;
    };
    readonly Eiffel: {
        readonly type: "programming";
        readonly color: "#4d6977";
        readonly extensions: [".e"];
        readonly tmScope: "source.eiffel";
        readonly aceMode: "eiffel";
        readonly codemirrorMode: "eiffel";
        readonly codemirrorMimeType: "text/x-eiffel";
        readonly languageId: 99;
    };
    readonly Elixir: {
        readonly type: "programming";
        readonly color: "#6e4a7e";
        readonly extensions: [".ex", ".exs"];
        readonly tmScope: "source.elixir";
        readonly aceMode: "elixir";
        readonly filenames: ["mix.lock"];
        readonly interpreters: ["elixir"];
        readonly languageId: 100;
    };
    readonly Elm: {
        readonly type: "programming";
        readonly color: "#60B5CC";
        readonly extensions: [".elm"];
        readonly tmScope: "source.elm";
        readonly aceMode: "elm";
        readonly codemirrorMode: "elm";
        readonly codemirrorMimeType: "text/x-elm";
        readonly languageId: 101;
    };
    readonly 'Emacs Lisp': {
        readonly type: "programming";
        readonly tmScope: "source.emacs.lisp";
        readonly color: "#c065db";
        readonly aliases: ["elisp", "emacs"];
        readonly filenames: [".abbrev_defs", ".emacs", ".emacs.desktop", ".gnus", ".spacemacs", ".viper", "Cask", "Project.ede", "_emacs", "abbrev_defs"];
        readonly extensions: [".el", ".emacs", ".emacs.desktop"];
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 102;
    };
    readonly EmberScript: {
        readonly type: "programming";
        readonly color: "#FFF4F3";
        readonly extensions: [".em", ".emberscript"];
        readonly tmScope: "source.coffee";
        readonly aceMode: "coffee";
        readonly codemirrorMode: "coffeescript";
        readonly codemirrorMimeType: "text/x-coffeescript";
        readonly languageId: 103;
    };
    readonly Erlang: {
        readonly type: "programming";
        readonly color: "#B83998";
        readonly extensions: [".erl", ".app.src", ".es", ".escript", ".hrl", ".xrl", ".yrl"];
        readonly filenames: ["Emakefile", "rebar.config", "rebar.config.lock", "rebar.lock"];
        readonly tmScope: "source.erlang";
        readonly aceMode: "erlang";
        readonly codemirrorMode: "erlang";
        readonly codemirrorMimeType: "text/x-erlang";
        readonly interpreters: ["escript"];
        readonly languageId: 104;
    };
    readonly 'F#': {
        readonly type: "programming";
        readonly color: "#b845fc";
        readonly aliases: ["fsharp"];
        readonly extensions: [".fs", ".fsi", ".fsx"];
        readonly tmScope: "source.fsharp";
        readonly aceMode: "text";
        readonly codemirrorMode: "mllike";
        readonly codemirrorMimeType: "text/x-fsharp";
        readonly languageId: 105;
    };
    readonly 'F*': {
        readonly fsName: "Fstar";
        readonly type: "programming";
        readonly color: "#572e30";
        readonly aliases: ["fstar"];
        readonly extensions: [".fst"];
        readonly tmScope: "source.fstar";
        readonly aceMode: "text";
        readonly languageId: 336943375;
    };
    readonly 'FIGlet Font': {
        readonly type: "data";
        readonly color: "#FFDDBB";
        readonly aliases: ["FIGfont"];
        readonly extensions: [".flf"];
        readonly tmScope: "source.figfont";
        readonly aceMode: "text";
        readonly languageId: 686129783;
    };
    readonly FLUX: {
        readonly type: "programming";
        readonly color: "#88ccff";
        readonly extensions: [".fx", ".flux"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 106;
    };
    readonly Factor: {
        readonly type: "programming";
        readonly color: "#636746";
        readonly extensions: [".factor"];
        readonly filenames: [".factor-boot-rc", ".factor-rc"];
        readonly tmScope: "source.factor";
        readonly aceMode: "text";
        readonly codemirrorMode: "factor";
        readonly codemirrorMimeType: "text/x-factor";
        readonly languageId: 108;
    };
    readonly Fancy: {
        readonly type: "programming";
        readonly color: "#7b9db4";
        readonly extensions: [".fy", ".fancypack"];
        readonly filenames: ["Fakefile"];
        readonly tmScope: "source.fancy";
        readonly aceMode: "text";
        readonly languageId: 109;
    };
    readonly Fantom: {
        readonly type: "programming";
        readonly color: "#14253c";
        readonly extensions: [".fan"];
        readonly tmScope: "source.fan";
        readonly aceMode: "text";
        readonly languageId: 110;
    };
    readonly Faust: {
        readonly type: "programming";
        readonly color: "#c37240";
        readonly extensions: [".dsp"];
        readonly tmScope: "source.faust";
        readonly aceMode: "text";
        readonly languageId: 622529198;
    };
    readonly Fennel: {
        readonly type: "programming";
        readonly tmScope: "source.fnl";
        readonly aceMode: "text";
        readonly color: "#fff3d7";
        readonly interpreters: ["fennel"];
        readonly extensions: [".fnl"];
        readonly languageId: 239946126;
    };
    readonly 'Filebench WML': {
        readonly type: "programming";
        readonly color: "#F6B900";
        readonly extensions: [".f"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 111;
    };
    readonly Filterscript: {
        readonly type: "programming";
        readonly group: "RenderScript";
        readonly extensions: [".fs"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 112;
    };
    readonly Fluent: {
        readonly type: "programming";
        readonly color: "#ffcc33";
        readonly extensions: [".ftl"];
        readonly tmScope: "source.ftl";
        readonly aceMode: "text";
        readonly languageId: 206353404;
    };
    readonly Formatted: {
        readonly type: "data";
        readonly extensions: [".for", ".eam.fs"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 113;
    };
    readonly Forth: {
        readonly type: "programming";
        readonly color: "#341708";
        readonly extensions: [".fth", ".4th", ".f", ".for", ".forth", ".fr", ".frt", ".fs"];
        readonly tmScope: "source.forth";
        readonly aceMode: "forth";
        readonly codemirrorMode: "forth";
        readonly codemirrorMimeType: "text/x-forth";
        readonly languageId: 114;
    };
    readonly Fortran: {
        readonly group: "Fortran";
        readonly type: "programming";
        readonly color: "#4d41b1";
        readonly extensions: [".f", ".f77", ".for", ".fpp"];
        readonly tmScope: "source.fortran";
        readonly aceMode: "text";
        readonly codemirrorMode: "fortran";
        readonly codemirrorMimeType: "text/x-fortran";
        readonly languageId: 107;
    };
    readonly 'Fortran Free Form': {
        readonly group: "Fortran";
        readonly color: "#4d41b1";
        readonly type: "programming";
        readonly extensions: [".f90", ".f03", ".f08", ".f95"];
        readonly tmScope: "source.fortran.modern";
        readonly aceMode: "text";
        readonly codemirrorMode: "fortran";
        readonly codemirrorMimeType: "text/x-fortran";
        readonly languageId: 761352333;
    };
    readonly FreeBasic: {
        readonly type: "programming";
        readonly color: "#867db1";
        readonly extensions: [".bi", ".bas"];
        readonly tmScope: "source.vbnet";
        readonly aliases: ["fb"];
        readonly aceMode: "text";
        readonly codemirrorMode: "vb";
        readonly codemirrorMimeType: "text/x-vb";
        readonly languageId: 472896659;
    };
    readonly FreeMarker: {
        readonly type: "programming";
        readonly color: "#0050b2";
        readonly aliases: ["ftl"];
        readonly extensions: [".ftl"];
        readonly tmScope: "text.html.ftl";
        readonly aceMode: "ftl";
        readonly languageId: 115;
    };
    readonly Frege: {
        readonly type: "programming";
        readonly color: "#00cafe";
        readonly extensions: [".fr"];
        readonly tmScope: "source.haskell";
        readonly aceMode: "haskell";
        readonly languageId: 116;
    };
    readonly Futhark: {
        readonly type: "programming";
        readonly color: "#5f021f";
        readonly extensions: [".fut"];
        readonly tmScope: "source.futhark";
        readonly aceMode: "text";
        readonly languageId: 97358117;
    };
    readonly 'G-code': {
        readonly type: "programming";
        readonly color: "#D08CF2";
        readonly extensions: [".g", ".cnc", ".gco", ".gcode"];
        readonly tmScope: "source.gcode";
        readonly aceMode: "gcode";
        readonly languageId: 117;
    };
    readonly GAML: {
        readonly type: "programming";
        readonly color: "#FFC766";
        readonly extensions: [".gaml"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 290345951;
    };
    readonly GAMS: {
        readonly type: "programming";
        readonly color: "#f49a22";
        readonly extensions: [".gms"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 118;
    };
    readonly GAP: {
        readonly type: "programming";
        readonly color: "#0000cc";
        readonly extensions: [".g", ".gap", ".gd", ".gi", ".tst"];
        readonly tmScope: "source.gap";
        readonly aceMode: "text";
        readonly languageId: 119;
    };
    readonly GDB: {
        readonly type: "programming";
        readonly extensions: [".gdb", ".gdbinit"];
        readonly tmScope: "source.gdb";
        readonly aceMode: "text";
        readonly languageId: 122;
    };
    readonly GDScript: {
        readonly type: "programming";
        readonly color: "#355570";
        readonly extensions: [".gd"];
        readonly tmScope: "source.gdscript";
        readonly aceMode: "text";
        readonly languageId: 123;
    };
    readonly GEDCOM: {
        readonly type: "data";
        readonly color: "#003058";
        readonly aceMode: "text";
        readonly extensions: [".ged"];
        readonly tmScope: "source.gedcom";
        readonly languageId: 459577965;
    };
    readonly GLSL: {
        readonly type: "programming";
        readonly color: "#5686a5";
        readonly extensions: [".glsl", ".fp", ".frag", ".frg", ".fs", ".fsh", ".fshader", ".geo", ".geom", ".glslf", ".glslv", ".gs", ".gshader", ".shader", ".tesc", ".tese", ".vert", ".vrx", ".vsh", ".vshader"];
        readonly tmScope: "source.glsl";
        readonly aceMode: "glsl";
        readonly languageId: 124;
    };
    readonly GN: {
        readonly type: "data";
        readonly extensions: [".gn", ".gni"];
        readonly interpreters: ["gn"];
        readonly filenames: [".gn"];
        readonly tmScope: "source.gn";
        readonly aceMode: "python";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly languageId: 302957008;
    };
    readonly 'Game Maker Language': {
        readonly type: "programming";
        readonly color: "#71b417";
        readonly extensions: [".gml"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 125;
    };
    readonly 'Gemfile.lock': {
        readonly type: "data";
        readonly color: "#701516";
        readonly searchable: false;
        readonly tmScope: "source.gemfile-lock";
        readonly aceMode: "text";
        readonly filenames: ["Gemfile.lock"];
        readonly languageId: 907065713;
    };
    readonly Genie: {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly extensions: [".gs"];
        readonly color: "#fb855d";
        readonly tmScope: "none";
        readonly languageId: 792408528;
    };
    readonly Genshi: {
        readonly type: "programming";
        readonly color: "#951531";
        readonly extensions: [".kid"];
        readonly tmScope: "text.xml.genshi";
        readonly aliases: ["xml+genshi", "xml+kid"];
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 126;
    };
    readonly 'Gentoo Ebuild': {
        readonly type: "programming";
        readonly color: "#9400ff";
        readonly group: "Shell";
        readonly extensions: [".ebuild"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 127;
    };
    readonly 'Gentoo Eclass': {
        readonly type: "programming";
        readonly color: "#9400ff";
        readonly group: "Shell";
        readonly extensions: [".eclass"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 128;
    };
    readonly 'Gerber Image': {
        readonly type: "data";
        readonly color: "#d20b00";
        readonly aliases: ["rs-274x"];
        readonly extensions: [".gbr", ".cmp", ".gbl", ".gbo", ".gbp", ".gbs", ".gko", ".gml", ".gpb", ".gpt", ".gtl", ".gto", ".gtp", ".gts", ".ncl", ".sol"];
        readonly interpreters: ["gerbv", "gerbview"];
        readonly tmScope: "source.gerber";
        readonly aceMode: "text";
        readonly languageId: 404627610;
    };
    readonly 'Gettext Catalog': {
        readonly type: "prose";
        readonly aliases: ["pot"];
        readonly extensions: [".po", ".pot"];
        readonly tmScope: "source.po";
        readonly aceMode: "text";
        readonly languageId: 129;
    };
    readonly Gherkin: {
        readonly type: "programming";
        readonly extensions: [".feature", ".story"];
        readonly tmScope: "text.gherkin.feature";
        readonly aliases: ["cucumber"];
        readonly aceMode: "text";
        readonly color: "#5B2063";
        readonly languageId: 76;
    };
    readonly 'Git Attributes': {
        readonly type: "data";
        readonly color: "#F44D27";
        readonly group: "INI";
        readonly aliases: ["gitattributes"];
        readonly filenames: [".gitattributes"];
        readonly tmScope: "source.gitattributes";
        readonly aceMode: "gitignore";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 956324166;
    };
    readonly 'Git Config': {
        readonly type: "data";
        readonly color: "#F44D27";
        readonly group: "INI";
        readonly aliases: ["gitconfig", "gitmodules"];
        readonly extensions: [".gitconfig"];
        readonly filenames: [".gitconfig", ".gitmodules"];
        readonly aceMode: "ini";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly tmScope: "source.gitconfig";
        readonly languageId: 807968997;
    };
    readonly Glyph: {
        readonly type: "programming";
        readonly color: "#c1ac7f";
        readonly extensions: [".glf"];
        readonly tmScope: "source.tcl";
        readonly aceMode: "tcl";
        readonly codemirrorMode: "tcl";
        readonly codemirrorMimeType: "text/x-tcl";
        readonly languageId: 130;
    };
    readonly 'Glyph Bitmap Distribution Format': {
        readonly type: "data";
        readonly extensions: [".bdf"];
        readonly tmScope: "source.bdf";
        readonly aceMode: "text";
        readonly languageId: 997665271;
    };
    readonly Gnuplot: {
        readonly type: "programming";
        readonly color: "#f0a9f0";
        readonly extensions: [".gp", ".gnu", ".gnuplot", ".p", ".plot", ".plt"];
        readonly interpreters: ["gnuplot"];
        readonly tmScope: "source.gnuplot";
        readonly aceMode: "text";
        readonly languageId: 131;
    };
    readonly Go: {
        readonly type: "programming";
        readonly color: "#00ADD8";
        readonly aliases: ["golang"];
        readonly extensions: [".go"];
        readonly tmScope: "source.go";
        readonly aceMode: "golang";
        readonly codemirrorMode: "go";
        readonly codemirrorMimeType: "text/x-go";
        readonly languageId: 132;
    };
    readonly 'Go Checksums': {
        readonly type: "data";
        readonly color: "#00ADD8";
        readonly aliases: ["go.sum", "go sum"];
        readonly filenames: ["go.sum"];
        readonly tmScope: "go.sum";
        readonly aceMode: "text";
        readonly languageId: 1054391671;
    };
    readonly 'Go Module': {
        readonly type: "data";
        readonly color: "#00ADD8";
        readonly aliases: ["go.mod", "go mod"];
        readonly filenames: ["go.mod"];
        readonly tmScope: "go.mod";
        readonly aceMode: "text";
        readonly languageId: 947461016;
    };
    readonly Golo: {
        readonly type: "programming";
        readonly color: "#88562A";
        readonly extensions: [".golo"];
        readonly tmScope: "source.golo";
        readonly aceMode: "text";
        readonly languageId: 133;
    };
    readonly Gosu: {
        readonly type: "programming";
        readonly color: "#82937f";
        readonly extensions: [".gs", ".gst", ".gsx", ".vark"];
        readonly tmScope: "source.gosu.2";
        readonly aceMode: "text";
        readonly languageId: 134;
    };
    readonly Grace: {
        readonly type: "programming";
        readonly color: "#615f8b";
        readonly extensions: [".grace"];
        readonly tmScope: "source.grace";
        readonly aceMode: "text";
        readonly languageId: 135;
    };
    readonly Gradle: {
        readonly type: "data";
        readonly color: "#02303a";
        readonly extensions: [".gradle"];
        readonly tmScope: "source.groovy.gradle";
        readonly aceMode: "text";
        readonly languageId: 136;
    };
    readonly 'Grammatical Framework': {
        readonly type: "programming";
        readonly aliases: ["gf"];
        readonly extensions: [".gf"];
        readonly color: "#ff0000";
        readonly tmScope: "source.gf";
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly languageId: 137;
    };
    readonly 'Graph Modeling Language': {
        readonly type: "data";
        readonly extensions: [".gml"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 138;
    };
    readonly GraphQL: {
        readonly type: "data";
        readonly color: "#e10098";
        readonly extensions: [".graphql", ".gql", ".graphqls"];
        readonly tmScope: "source.graphql";
        readonly aceMode: "text";
        readonly languageId: 139;
    };
    readonly 'Graphviz (DOT)': {
        readonly type: "data";
        readonly color: "#2596be";
        readonly tmScope: "source.dot";
        readonly extensions: [".dot", ".gv"];
        readonly aceMode: "text";
        readonly languageId: 140;
    };
    readonly Groovy: {
        readonly type: "programming";
        readonly tmScope: "source.groovy";
        readonly aceMode: "groovy";
        readonly codemirrorMode: "groovy";
        readonly codemirrorMimeType: "text/x-groovy";
        readonly color: "#4298b8";
        readonly extensions: [".groovy", ".grt", ".gtpl", ".gvy"];
        readonly interpreters: ["groovy"];
        readonly filenames: ["Jenkinsfile"];
        readonly languageId: 142;
    };
    readonly 'Groovy Server Pages': {
        readonly type: "programming";
        readonly color: "#4298b8";
        readonly group: "Groovy";
        readonly aliases: ["gsp", "java server page"];
        readonly extensions: [".gsp"];
        readonly tmScope: "text.html.jsp";
        readonly aceMode: "jsp";
        readonly codemirrorMode: "htmlembedded";
        readonly codemirrorMimeType: "application/x-jsp";
        readonly languageId: 143;
    };
    readonly HAProxy: {
        readonly type: "data";
        readonly color: "#106da9";
        readonly extensions: [".cfg"];
        readonly filenames: ["haproxy.cfg"];
        readonly tmScope: "source.haproxy-config";
        readonly aceMode: "text";
        readonly languageId: 366607477;
    };
    readonly HCL: {
        readonly type: "programming";
        readonly extensions: [".hcl", ".nomad", ".tf", ".tfvars", ".workflow"];
        readonly aliases: ["HashiCorp Configuration Language", "terraform"];
        readonly aceMode: "ruby";
        readonly codemirrorMode: "ruby";
        readonly codemirrorMimeType: "text/x-ruby";
        readonly tmScope: "source.terraform";
        readonly languageId: 144;
    };
    readonly HLSL: {
        readonly type: "programming";
        readonly color: "#aace60";
        readonly extensions: [".hlsl", ".cginc", ".fx", ".fxh", ".hlsli"];
        readonly aceMode: "text";
        readonly tmScope: "source.hlsl";
        readonly languageId: 145;
    };
    readonly HTML: {
        readonly type: "markup";
        readonly tmScope: "text.html.basic";
        readonly aceMode: "html";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly color: "#e34c26";
        readonly aliases: ["xhtml"];
        readonly extensions: [".html", ".hta", ".htm", ".html.hl", ".inc", ".xht", ".xhtml"];
        readonly languageId: 146;
    };
    readonly 'HTML+ECR': {
        readonly type: "markup";
        readonly color: "#2e1052";
        readonly tmScope: "text.html.ecr";
        readonly group: "HTML";
        readonly aliases: ["ecr"];
        readonly extensions: [".ecr"];
        readonly aceMode: "text";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 148;
    };
    readonly 'HTML+EEX': {
        readonly type: "markup";
        readonly color: "#6e4a7e";
        readonly tmScope: "text.html.elixir";
        readonly group: "HTML";
        readonly aliases: ["eex", "leex"];
        readonly extensions: [".eex", ".html.leex"];
        readonly aceMode: "text";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 149;
    };
    readonly 'HTML+ERB': {
        readonly type: "markup";
        readonly color: "#701516";
        readonly tmScope: "text.html.erb";
        readonly group: "HTML";
        readonly aliases: ["erb", "rhtml", "html+ruby"];
        readonly extensions: [".erb", ".erb.deface", ".rhtml"];
        readonly aceMode: "text";
        readonly codemirrorMode: "htmlembedded";
        readonly codemirrorMimeType: "application/x-erb";
        readonly languageId: 150;
    };
    readonly 'HTML+PHP': {
        readonly type: "markup";
        readonly color: "#4f5d95";
        readonly tmScope: "text.html.php";
        readonly group: "HTML";
        readonly extensions: [".phtml"];
        readonly aceMode: "php";
        readonly codemirrorMode: "php";
        readonly codemirrorMimeType: "application/x-httpd-php";
        readonly languageId: 151;
    };
    readonly 'HTML+Razor': {
        readonly type: "markup";
        readonly color: "#512be4";
        readonly tmScope: "text.html.cshtml";
        readonly group: "HTML";
        readonly aliases: ["razor"];
        readonly extensions: [".cshtml", ".razor"];
        readonly aceMode: "razor";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 479039817;
    };
    readonly HTTP: {
        readonly type: "data";
        readonly color: "#005C9C";
        readonly extensions: [".http"];
        readonly tmScope: "source.httpspec";
        readonly aceMode: "text";
        readonly codemirrorMode: "http";
        readonly codemirrorMimeType: "message/http";
        readonly languageId: 152;
    };
    readonly HXML: {
        readonly type: "data";
        readonly color: "#f68712";
        readonly aceMode: "text";
        readonly extensions: [".hxml"];
        readonly tmScope: "source.hxml";
        readonly languageId: 786683730;
    };
    readonly Hack: {
        readonly type: "programming";
        readonly aceMode: "php";
        readonly codemirrorMode: "php";
        readonly codemirrorMimeType: "application/x-httpd-php";
        readonly extensions: [".hack", ".hh", ".hhi", ".php"];
        readonly tmScope: "source.hack";
        readonly color: "#878787";
        readonly languageId: 153;
    };
    readonly Haml: {
        readonly type: "markup";
        readonly color: "#ece2a9";
        readonly extensions: [".haml", ".haml.deface"];
        readonly tmScope: "text.haml";
        readonly aceMode: "haml";
        readonly codemirrorMode: "haml";
        readonly codemirrorMimeType: "text/x-haml";
        readonly languageId: 154;
    };
    readonly Handlebars: {
        readonly type: "markup";
        readonly color: "#f7931e";
        readonly aliases: ["hbs", "htmlbars"];
        readonly extensions: [".handlebars", ".hbs"];
        readonly tmScope: "text.html.handlebars";
        readonly aceMode: "handlebars";
        readonly languageId: 155;
    };
    readonly Harbour: {
        readonly type: "programming";
        readonly color: "#0e60e3";
        readonly extensions: [".hb"];
        readonly tmScope: "source.harbour";
        readonly aceMode: "text";
        readonly languageId: 156;
    };
    readonly Haskell: {
        readonly type: "programming";
        readonly color: "#5e5086";
        readonly extensions: [".hs", ".hs-boot", ".hsc"];
        readonly interpreters: ["runghc", "runhaskell", "runhugs"];
        readonly tmScope: "source.haskell";
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly languageId: 157;
    };
    readonly Haxe: {
        readonly type: "programming";
        readonly aceMode: "haxe";
        readonly codemirrorMode: "haxe";
        readonly codemirrorMimeType: "text/x-haxe";
        readonly color: "#df7900";
        readonly extensions: [".hx", ".hxsl"];
        readonly tmScope: "source.hx";
        readonly languageId: 158;
    };
    readonly HiveQL: {
        readonly type: "programming";
        readonly extensions: [".q", ".hql"];
        readonly color: "#dce200";
        readonly tmScope: "source.hql";
        readonly aceMode: "sql";
        readonly languageId: 931814087;
    };
    readonly HolyC: {
        readonly type: "programming";
        readonly color: "#ffefaf";
        readonly extensions: [".hc"];
        readonly tmScope: "source.hc";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 928121743;
    };
    readonly Hy: {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly color: "#7790B2";
        readonly extensions: [".hy"];
        readonly interpreters: ["hy"];
        readonly aliases: ["hylang"];
        readonly tmScope: "source.hy";
        readonly languageId: 159;
    };
    readonly HyPhy: {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly extensions: [".bf"];
        readonly tmScope: "none";
        readonly languageId: 160;
    };
    readonly IDL: {
        readonly type: "programming";
        readonly color: "#a3522f";
        readonly extensions: [".pro", ".dlm"];
        readonly tmScope: "source.idl";
        readonly aceMode: "text";
        readonly codemirrorMode: "idl";
        readonly codemirrorMimeType: "text/x-idl";
        readonly languageId: 161;
    };
    readonly 'IGOR Pro': {
        readonly type: "programming";
        readonly color: "#0000cc";
        readonly extensions: [".ipf"];
        readonly aliases: ["igor", "igorpro"];
        readonly tmScope: "source.igor";
        readonly aceMode: "text";
        readonly languageId: 162;
    };
    readonly INI: {
        readonly type: "data";
        readonly color: "#d1dbe0";
        readonly extensions: [".ini", ".cfg", ".dof", ".lektorproject", ".prefs", ".pro", ".properties"];
        readonly filenames: ["buildozer.spec"];
        readonly tmScope: "source.ini";
        readonly aliases: ["dosini"];
        readonly aceMode: "ini";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly languageId: 163;
    };
    readonly 'IRC log': {
        readonly type: "data";
        readonly aliases: ["irc", "irc logs"];
        readonly extensions: [".irclog", ".weechatlog"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly codemirrorMode: "mirc";
        readonly codemirrorMimeType: "text/mirc";
        readonly languageId: 164;
    };
    readonly Idris: {
        readonly type: "programming";
        readonly color: "#b30000";
        readonly extensions: [".idr", ".lidr"];
        readonly aceMode: "text";
        readonly tmScope: "source.idris";
        readonly languageId: 165;
    };
    readonly 'Ignore List': {
        readonly type: "data";
        readonly color: "#000000";
        readonly group: "INI";
        readonly aliases: ["ignore", "gitignore", "git-ignore"];
        readonly extensions: [".gitignore"];
        readonly filenames: [".atomignore", ".babelignore", ".bzrignore", ".coffeelintignore", ".cvsignore", ".dockerignore", ".eleventyignore", ".eslintignore", ".gitignore", ".markdownlintignore", ".nodemonignore", ".npmignore", ".prettierignore", ".stylelintignore", ".vscodeignore", "gitignore-global", "gitignore_global"];
        readonly aceMode: "gitignore";
        readonly tmScope: "source.gitignore";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 74444240;
    };
    readonly 'ImageJ Macro': {
        readonly type: "programming";
        readonly color: "#99AAFF";
        readonly aliases: ["ijm"];
        readonly extensions: [".ijm"];
        readonly aceMode: "text";
        readonly tmScope: "none";
        readonly languageId: 575143428;
    };
    readonly 'Inform 7': {
        readonly type: "programming";
        readonly wrap: true;
        readonly extensions: [".ni", ".i7x"];
        readonly tmScope: "source.inform7";
        readonly aliases: ["i7", "inform7"];
        readonly aceMode: "text";
        readonly languageId: 166;
    };
    readonly 'Inno Setup': {
        readonly type: "programming";
        readonly color: "#264b99";
        readonly extensions: [".iss", ".isl"];
        readonly tmScope: "source.inno";
        readonly aceMode: "text";
        readonly languageId: 167;
    };
    readonly Io: {
        readonly type: "programming";
        readonly color: "#a9188d";
        readonly extensions: [".io"];
        readonly interpreters: ["io"];
        readonly tmScope: "source.io";
        readonly aceMode: "io";
        readonly languageId: 168;
    };
    readonly Ioke: {
        readonly type: "programming";
        readonly color: "#078193";
        readonly extensions: [".ik"];
        readonly interpreters: ["ioke"];
        readonly tmScope: "source.ioke";
        readonly aceMode: "text";
        readonly languageId: 169;
    };
    readonly Isabelle: {
        readonly type: "programming";
        readonly color: "#FEFE00";
        readonly extensions: [".thy"];
        readonly tmScope: "source.isabelle.theory";
        readonly aceMode: "text";
        readonly languageId: 170;
    };
    readonly 'Isabelle ROOT': {
        readonly type: "programming";
        readonly color: "#FEFE00";
        readonly group: "Isabelle";
        readonly filenames: ["ROOT"];
        readonly tmScope: "source.isabelle.root";
        readonly aceMode: "text";
        readonly languageId: 171;
    };
    readonly J: {
        readonly type: "programming";
        readonly color: "#9EEDFF";
        readonly extensions: [".ijs"];
        readonly interpreters: ["jconsole"];
        readonly tmScope: "source.j";
        readonly aceMode: "text";
        readonly languageId: 172;
    };
    readonly 'JAR Manifest': {
        readonly type: "data";
        readonly color: "#b07219";
        readonly filenames: ["MANIFEST.MF"];
        readonly tmScope: "source.yaml";
        readonly aceMode: "text";
        readonly languageId: 447261135;
    };
    readonly JFlex: {
        readonly type: "programming";
        readonly color: "#DBCA00";
        readonly group: "Lex";
        readonly extensions: [".flex", ".jflex"];
        readonly tmScope: "source.jflex";
        readonly aceMode: "text";
        readonly languageId: 173;
    };
    readonly JSON: {
        readonly type: "data";
        readonly color: "#292929";
        readonly tmScope: "source.json";
        readonly aceMode: "json";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly extensions: [".json", ".avsc", ".geojson", ".gltf", ".har", ".ice", ".JSON-tmLanguage", ".jsonl", ".mcmeta", ".tfstate", ".tfstate.backup", ".topojson", ".webapp", ".webmanifest", ".yy", ".yyp"];
        readonly filenames: [".arcconfig", ".auto-changelog", ".c8rc", ".htmlhintrc", ".imgbotconfig", ".nycrc", ".tern-config", ".tern-project", ".watchmanconfig", "Pipfile.lock", "composer.lock", "mcmod.info"];
        readonly languageId: 174;
    };
    readonly 'JSON with Comments': {
        readonly type: "data";
        readonly color: "#292929";
        readonly group: "JSON";
        readonly tmScope: "source.js";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "text/javascript";
        readonly aliases: ["jsonc"];
        readonly extensions: [".jsonc", ".sublime-build", ".sublime-commands", ".sublime-completions", ".sublime-keymap", ".sublime-macro", ".sublime-menu", ".sublime-mousemap", ".sublime-project", ".sublime-settings", ".sublime-theme", ".sublime-workspace", ".sublime_metrics", ".sublime_session"];
        readonly filenames: [".babelrc", ".eslintrc.json", ".jscsrc", ".jshintrc", ".jslintrc", "api-extractor.json", "devcontainer.json", "jsconfig.json", "language-configuration.json", "tsconfig.json", "tslint.json"];
        readonly languageId: 423;
    };
    readonly JSON5: {
        readonly type: "data";
        readonly color: "#267CB9";
        readonly extensions: [".json5"];
        readonly tmScope: "source.js";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly languageId: 175;
    };
    readonly JSONLD: {
        readonly type: "data";
        readonly color: "#0c479c";
        readonly extensions: [".jsonld"];
        readonly tmScope: "source.js";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly languageId: 176;
    };
    readonly JSONiq: {
        readonly color: "#40d47e";
        readonly type: "programming";
        readonly aceMode: "jsoniq";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly extensions: [".jq"];
        readonly tmScope: "source.jsoniq";
        readonly languageId: 177;
    };
    readonly Jasmin: {
        readonly type: "programming";
        readonly color: "#d03600";
        readonly aceMode: "java";
        readonly extensions: [".j"];
        readonly tmScope: "source.jasmin";
        readonly languageId: 180;
    };
    readonly Java: {
        readonly type: "programming";
        readonly tmScope: "source.java";
        readonly aceMode: "java";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-java";
        readonly color: "#b07219";
        readonly extensions: [".java", ".jav"];
        readonly languageId: 181;
    };
    readonly 'Java Properties': {
        readonly type: "data";
        readonly color: "#2A6277";
        readonly extensions: [".properties"];
        readonly tmScope: "source.java-properties";
        readonly aceMode: "properties";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly languageId: 519377561;
    };
    readonly 'Java Server Pages': {
        readonly type: "programming";
        readonly color: "#2A6277";
        readonly group: "Java";
        readonly aliases: ["jsp"];
        readonly extensions: [".jsp"];
        readonly tmScope: "text.html.jsp";
        readonly aceMode: "jsp";
        readonly codemirrorMode: "htmlembedded";
        readonly codemirrorMimeType: "application/x-jsp";
        readonly languageId: 182;
    };
    readonly JavaScript: {
        readonly type: "programming";
        readonly tmScope: "source.js";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "text/javascript";
        readonly color: "#f1e05a";
        readonly aliases: ["js", "node"];
        readonly extensions: [".js", "._js", ".bones", ".cjs", ".es", ".es6", ".frag", ".gs", ".jake", ".javascript", ".jsb", ".jscad", ".jsfl", ".jsm", ".jss", ".jsx", ".mjs", ".njs", ".pac", ".sjs", ".ssjs", ".xsjs", ".xsjslib"];
        readonly filenames: ["Jakefile"];
        readonly interpreters: ["chakra", "d8", "gjs", "js", "node", "nodejs", "qjs", "rhino", "v8", "v8-shell"];
        readonly languageId: 183;
    };
    readonly 'JavaScript+ERB': {
        readonly type: "programming";
        readonly color: "#f1e05a";
        readonly tmScope: "source.js";
        readonly group: "JavaScript";
        readonly extensions: [".js.erb"];
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/javascript";
        readonly languageId: 914318960;
    };
    readonly 'Jest Snapshot': {
        readonly type: "data";
        readonly color: "#15c213";
        readonly tmScope: "source.jest.snap";
        readonly extensions: [".snap"];
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/javascript";
        readonly languageId: 774635084;
    };
    readonly Jinja: {
        readonly type: "markup";
        readonly color: "#a52a22";
        readonly aliases: ["django", "html+django", "html+jinja", "htmldjango"];
        readonly extensions: [".jinja", ".j2", ".jinja2"];
        readonly tmScope: "text.html.django";
        readonly aceMode: "django";
        readonly codemirrorMode: "django";
        readonly codemirrorMimeType: "text/x-django";
        readonly languageId: 147;
    };
    readonly Jison: {
        readonly type: "programming";
        readonly color: "#56b3cb";
        readonly group: "Yacc";
        readonly extensions: [".jison"];
        readonly tmScope: "source.jison";
        readonly aceMode: "text";
        readonly languageId: 284531423;
    };
    readonly 'Jison Lex': {
        readonly type: "programming";
        readonly color: "#56b3cb";
        readonly group: "Lex";
        readonly extensions: [".jisonlex"];
        readonly tmScope: "source.jisonlex";
        readonly aceMode: "text";
        readonly languageId: 406395330;
    };
    readonly Jolie: {
        readonly type: "programming";
        readonly extensions: [".ol", ".iol"];
        readonly interpreters: ["jolie"];
        readonly color: "#843179";
        readonly aceMode: "text";
        readonly tmScope: "source.jolie";
        readonly languageId: 998078858;
    };
    readonly Jsonnet: {
        readonly color: "#0064bd";
        readonly type: "programming";
        readonly aceMode: "text";
        readonly extensions: [".jsonnet", ".libsonnet"];
        readonly tmScope: "source.jsonnet";
        readonly languageId: 664885656;
    };
    readonly Julia: {
        readonly type: "programming";
        readonly extensions: [".jl"];
        readonly interpreters: ["julia"];
        readonly color: "#a270ba";
        readonly tmScope: "source.julia";
        readonly aceMode: "julia";
        readonly codemirrorMode: "julia";
        readonly codemirrorMimeType: "text/x-julia";
        readonly languageId: 184;
    };
    readonly 'Jupyter Notebook': {
        readonly type: "markup";
        readonly aceMode: "json";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly tmScope: "source.json";
        readonly color: "#DA5B0B";
        readonly extensions: [".ipynb"];
        readonly filenames: ["Notebook"];
        readonly aliases: ["IPython Notebook"];
        readonly languageId: 185;
    };
    readonly KRL: {
        readonly type: "programming";
        readonly color: "#28430A";
        readonly extensions: [".krl"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 186;
    };
    readonly 'Kaitai Struct': {
        readonly type: "programming";
        readonly aliases: ["ksy"];
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly color: "#773b37";
        readonly extensions: [".ksy"];
        readonly tmScope: "source.yaml";
        readonly languageId: 818804755;
    };
    readonly KakouneScript: {
        readonly type: "programming";
        readonly color: "#6f8042";
        readonly tmScope: "source.kakscript";
        readonly aliases: ["kak", "kakscript"];
        readonly extensions: [".kak"];
        readonly filenames: ["kakrc"];
        readonly aceMode: "text";
        readonly languageId: 603336474;
    };
    readonly 'KiCad Layout': {
        readonly type: "data";
        readonly color: "#2f4aab";
        readonly aliases: ["pcbnew"];
        readonly extensions: [".kicad_pcb", ".kicad_mod", ".kicad_wks"];
        readonly filenames: ["fp-lib-table"];
        readonly tmScope: "source.pcb.sexp";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 187;
    };
    readonly 'KiCad Legacy Layout': {
        readonly type: "data";
        readonly color: "#2f4aab";
        readonly extensions: [".brd"];
        readonly tmScope: "source.pcb.board";
        readonly aceMode: "text";
        readonly languageId: 140848857;
    };
    readonly 'KiCad Schematic': {
        readonly type: "data";
        readonly color: "#2f4aab";
        readonly aliases: ["eeschema schematic"];
        readonly extensions: [".sch"];
        readonly tmScope: "source.pcb.schematic";
        readonly aceMode: "text";
        readonly languageId: 622447435;
    };
    readonly Kit: {
        readonly type: "markup";
        readonly aceMode: "html";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly extensions: [".kit"];
        readonly tmScope: "text.html.basic";
        readonly languageId: 188;
    };
    readonly Kotlin: {
        readonly type: "programming";
        readonly color: "#A97BFF";
        readonly extensions: [".kt", ".ktm", ".kts"];
        readonly tmScope: "source.kotlin";
        readonly aceMode: "text";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-kotlin";
        readonly languageId: 189;
    };
    readonly Kusto: {
        readonly type: "data";
        readonly extensions: [".csl"];
        readonly tmScope: "source.kusto";
        readonly aceMode: "text";
        readonly languageId: 225697190;
    };
    readonly LFE: {
        readonly type: "programming";
        readonly color: "#4C3023";
        readonly extensions: [".lfe"];
        readonly tmScope: "source.lisp";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 190;
    };
    readonly LLVM: {
        readonly type: "programming";
        readonly extensions: [".ll"];
        readonly tmScope: "source.llvm";
        readonly aceMode: "text";
        readonly color: "#185619";
        readonly languageId: 191;
    };
    readonly LOLCODE: {
        readonly type: "programming";
        readonly extensions: [".lol"];
        readonly color: "#cc9900";
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 192;
    };
    readonly LSL: {
        readonly type: "programming";
        readonly tmScope: "source.lsl";
        readonly aceMode: "lsl";
        readonly extensions: [".lsl", ".lslp"];
        readonly interpreters: ["lsl"];
        readonly color: "#3d9970";
        readonly languageId: 193;
    };
    readonly 'LTspice Symbol': {
        readonly type: "data";
        readonly extensions: [".asy"];
        readonly tmScope: "source.ltspice.symbol";
        readonly aceMode: "text";
        readonly codemirrorMode: "spreadsheet";
        readonly codemirrorMimeType: "text/x-spreadsheet";
        readonly languageId: 1013566805;
    };
    readonly LabVIEW: {
        readonly type: "programming";
        readonly color: "#fede06";
        readonly extensions: [".lvproj", ".lvlib"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 194;
    };
    readonly Lark: {
        readonly type: "data";
        readonly color: "#2980B9";
        readonly extensions: [".lark"];
        readonly tmScope: "source.lark";
        readonly aceMode: "text";
        readonly codemirrorMode: "ebnf";
        readonly codemirrorMimeType: "text/x-ebnf";
        readonly languageId: 758480799;
    };
    readonly Lasso: {
        readonly type: "programming";
        readonly color: "#999999";
        readonly extensions: [".lasso", ".las", ".lasso8", ".lasso9"];
        readonly tmScope: "file.lasso";
        readonly aliases: ["lassoscript"];
        readonly aceMode: "text";
        readonly languageId: 195;
    };
    readonly Latte: {
        readonly type: "markup";
        readonly color: "#f2a542";
        readonly extensions: [".latte"];
        readonly tmScope: "text.html.smarty";
        readonly aceMode: "smarty";
        readonly codemirrorMode: "smarty";
        readonly codemirrorMimeType: "text/x-smarty";
        readonly languageId: 196;
    };
    readonly Lean: {
        readonly type: "programming";
        readonly extensions: [".lean", ".hlean"];
        readonly tmScope: "source.lean";
        readonly aceMode: "text";
        readonly languageId: 197;
    };
    readonly Less: {
        readonly type: "markup";
        readonly color: "#1d365d";
        readonly extensions: [".less"];
        readonly tmScope: "source.css.less";
        readonly aceMode: "less";
        readonly codemirrorMode: "css";
        readonly codemirrorMimeType: "text/css";
        readonly languageId: 198;
    };
    readonly Lex: {
        readonly type: "programming";
        readonly color: "#DBCA00";
        readonly aliases: ["flex"];
        readonly extensions: [".l", ".lex"];
        readonly filenames: ["Lexer.x", "lexer.x"];
        readonly tmScope: "source.lex";
        readonly aceMode: "text";
        readonly languageId: 199;
    };
    readonly LilyPond: {
        readonly type: "programming";
        readonly color: "#9ccc7c";
        readonly extensions: [".ly", ".ily"];
        readonly tmScope: "source.lilypond";
        readonly aceMode: "text";
        readonly languageId: 200;
    };
    readonly Limbo: {
        readonly type: "programming";
        readonly extensions: [".b", ".m"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 201;
    };
    readonly 'Linker Script': {
        readonly type: "data";
        readonly extensions: [".ld", ".lds", ".x"];
        readonly filenames: ["ld.script"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 202;
    };
    readonly 'Linux Kernel Module': {
        readonly type: "data";
        readonly extensions: [".mod"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 203;
    };
    readonly Liquid: {
        readonly type: "markup";
        readonly color: "#67b8de";
        readonly extensions: [".liquid"];
        readonly tmScope: "text.html.liquid";
        readonly aceMode: "liquid";
        readonly languageId: 204;
    };
    readonly 'Literate Agda': {
        readonly type: "programming";
        readonly color: "#315665";
        readonly group: "Agda";
        readonly extensions: [".lagda"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 205;
    };
    readonly 'Literate CoffeeScript': {
        readonly type: "programming";
        readonly color: "#244776";
        readonly tmScope: "source.litcoffee";
        readonly group: "CoffeeScript";
        readonly aceMode: "text";
        readonly wrap: true;
        readonly aliases: ["litcoffee"];
        readonly extensions: [".litcoffee", ".coffee.md"];
        readonly languageId: 206;
    };
    readonly 'Literate Haskell': {
        readonly type: "programming";
        readonly color: "#5e5086";
        readonly group: "Haskell";
        readonly aliases: ["lhaskell", "lhs"];
        readonly extensions: [".lhs"];
        readonly tmScope: "text.tex.latex.haskell";
        readonly aceMode: "text";
        readonly codemirrorMode: "haskell-literate";
        readonly codemirrorMimeType: "text/x-literate-haskell";
        readonly languageId: 207;
    };
    readonly LiveScript: {
        readonly type: "programming";
        readonly color: "#499886";
        readonly aliases: ["live-script", "ls"];
        readonly extensions: [".ls", "._ls"];
        readonly filenames: ["Slakefile"];
        readonly tmScope: "source.livescript";
        readonly aceMode: "livescript";
        readonly codemirrorMode: "livescript";
        readonly codemirrorMimeType: "text/x-livescript";
        readonly languageId: 208;
    };
    readonly Logos: {
        readonly type: "programming";
        readonly extensions: [".xm", ".x", ".xi"];
        readonly aceMode: "text";
        readonly tmScope: "source.logos";
        readonly languageId: 209;
    };
    readonly Logtalk: {
        readonly type: "programming";
        readonly color: "#295b9a";
        readonly extensions: [".lgt", ".logtalk"];
        readonly tmScope: "source.logtalk";
        readonly aceMode: "text";
        readonly languageId: 210;
    };
    readonly LookML: {
        readonly type: "programming";
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly color: "#652B81";
        readonly extensions: [".lookml", ".model.lkml", ".view.lkml"];
        readonly tmScope: "source.yaml";
        readonly languageId: 211;
    };
    readonly LoomScript: {
        readonly type: "programming";
        readonly extensions: [".ls"];
        readonly tmScope: "source.loomscript";
        readonly aceMode: "text";
        readonly languageId: 212;
    };
    readonly Lua: {
        readonly type: "programming";
        readonly tmScope: "source.lua";
        readonly aceMode: "lua";
        readonly codemirrorMode: "lua";
        readonly codemirrorMimeType: "text/x-lua";
        readonly color: "#000080";
        readonly extensions: [".lua", ".fcgi", ".nse", ".p8", ".pd_lua", ".rbxs", ".rockspec", ".wlua"];
        readonly filenames: [".luacheckrc"];
        readonly interpreters: ["lua"];
        readonly languageId: 213;
    };
    readonly M: {
        readonly type: "programming";
        readonly aliases: ["mumps"];
        readonly extensions: [".mumps", ".m"];
        readonly aceMode: "text";
        readonly codemirrorMode: "mumps";
        readonly codemirrorMimeType: "text/x-mumps";
        readonly languageId: 214;
        readonly tmScope: "none";
    };
    readonly M4: {
        readonly type: "programming";
        readonly extensions: [".m4"];
        readonly tmScope: "source.m4";
        readonly aceMode: "text";
        readonly languageId: 215;
    };
    readonly M4Sugar: {
        readonly type: "programming";
        readonly group: "M4";
        readonly aliases: ["autoconf"];
        readonly extensions: [".m4"];
        readonly filenames: ["configure.ac"];
        readonly tmScope: "source.m4";
        readonly aceMode: "text";
        readonly languageId: 216;
    };
    readonly MATLAB: {
        readonly type: "programming";
        readonly color: "#e16737";
        readonly aliases: ["octave"];
        readonly extensions: [".matlab", ".m"];
        readonly tmScope: "source.matlab";
        readonly aceMode: "matlab";
        readonly codemirrorMode: "octave";
        readonly codemirrorMimeType: "text/x-octave";
        readonly languageId: 225;
    };
    readonly MAXScript: {
        readonly type: "programming";
        readonly color: "#00a6a6";
        readonly extensions: [".ms", ".mcr"];
        readonly tmScope: "source.maxscript";
        readonly aceMode: "text";
        readonly languageId: 217;
    };
    readonly MLIR: {
        readonly type: "programming";
        readonly color: "#5EC8DB";
        readonly extensions: [".mlir"];
        readonly tmScope: "source.mlir";
        readonly aceMode: "text";
        readonly languageId: 448253929;
    };
    readonly MQL4: {
        readonly type: "programming";
        readonly color: "#62A8D6";
        readonly extensions: [".mq4", ".mqh"];
        readonly tmScope: "source.mql5";
        readonly aceMode: "c_cpp";
        readonly languageId: 426;
    };
    readonly MQL5: {
        readonly type: "programming";
        readonly color: "#4A76B8";
        readonly extensions: [".mq5", ".mqh"];
        readonly tmScope: "source.mql5";
        readonly aceMode: "c_cpp";
        readonly languageId: 427;
    };
    readonly MTML: {
        readonly type: "markup";
        readonly color: "#b7e1f4";
        readonly extensions: [".mtml"];
        readonly tmScope: "text.html.basic";
        readonly aceMode: "html";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 218;
    };
    readonly MUF: {
        readonly type: "programming";
        readonly group: "Forth";
        readonly extensions: [".muf", ".m"];
        readonly tmScope: "none";
        readonly aceMode: "forth";
        readonly codemirrorMode: "forth";
        readonly codemirrorMimeType: "text/x-forth";
        readonly languageId: 219;
    };
    readonly Macaulay2: {
        readonly type: "programming";
        readonly extensions: [".m2"];
        readonly aliases: ["m2"];
        readonly interpreters: ["M2"];
        readonly aceMode: "text";
        readonly tmScope: "source.m2";
        readonly color: "#d8ffff";
        readonly languageId: 34167825;
    };
    readonly Makefile: {
        readonly type: "programming";
        readonly color: "#427819";
        readonly aliases: ["bsdmake", "make", "mf"];
        readonly extensions: [".mak", ".d", ".make", ".makefile", ".mk", ".mkfile"];
        readonly filenames: ["BSDmakefile", "GNUmakefile", "Kbuild", "Makefile", "Makefile.am", "Makefile.boot", "Makefile.frag", "Makefile.in", "Makefile.inc", "Makefile.wat", "makefile", "makefile.sco", "mkfile"];
        readonly interpreters: ["make"];
        readonly tmScope: "source.makefile";
        readonly aceMode: "makefile";
        readonly codemirrorMode: "cmake";
        readonly codemirrorMimeType: "text/x-cmake";
        readonly languageId: 220;
    };
    readonly Mako: {
        readonly type: "programming";
        readonly color: "#7e858d";
        readonly extensions: [".mako", ".mao"];
        readonly tmScope: "text.html.mako";
        readonly aceMode: "text";
        readonly languageId: 221;
    };
    readonly Markdown: {
        readonly type: "prose";
        readonly color: "#083fa1";
        readonly aliases: ["pandoc"];
        readonly aceMode: "markdown";
        readonly codemirrorMode: "gfm";
        readonly codemirrorMimeType: "text/x-gfm";
        readonly wrap: true;
        readonly extensions: [".md", ".markdown", ".mdown", ".mdwn", ".mdx", ".mkd", ".mkdn", ".mkdown", ".ronn", ".scd", ".workbook"];
        readonly filenames: ["contents.lr"];
        readonly tmScope: "source.gfm";
        readonly languageId: 222;
    };
    readonly Marko: {
        readonly type: "markup";
        readonly color: "#42bff2";
        readonly tmScope: "text.marko";
        readonly extensions: [".marko"];
        readonly aliases: ["markojs"];
        readonly aceMode: "text";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 932782397;
    };
    readonly Mask: {
        readonly type: "markup";
        readonly color: "#f97732";
        readonly aceMode: "mask";
        readonly extensions: [".mask"];
        readonly tmScope: "source.mask";
        readonly languageId: 223;
    };
    readonly Mathematica: {
        readonly type: "programming";
        readonly color: "#dd1100";
        readonly extensions: [".mathematica", ".cdf", ".m", ".ma", ".mt", ".nb", ".nbp", ".wl", ".wlt"];
        readonly aliases: ["mma", "wolfram", "wolfram language", "wolfram lang", "wl"];
        readonly tmScope: "source.mathematica";
        readonly aceMode: "text";
        readonly codemirrorMode: "mathematica";
        readonly codemirrorMimeType: "text/x-mathematica";
        readonly languageId: 224;
    };
    readonly 'Maven POM': {
        readonly type: "data";
        readonly group: "XML";
        readonly tmScope: "text.xml.pom";
        readonly filenames: ["pom.xml"];
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 226;
    };
    readonly Max: {
        readonly type: "programming";
        readonly color: "#c4a79c";
        readonly aliases: ["max/msp", "maxmsp"];
        readonly extensions: [".maxpat", ".maxhelp", ".maxproj", ".mxt", ".pat"];
        readonly tmScope: "source.json";
        readonly aceMode: "json";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/json";
        readonly languageId: 227;
    };
    readonly Mercury: {
        readonly type: "programming";
        readonly color: "#ff2b2b";
        readonly aceMode: "prolog";
        readonly interpreters: ["mmi"];
        readonly extensions: [".m", ".moo"];
        readonly tmScope: "source.mercury";
        readonly languageId: 229;
    };
    readonly Meson: {
        readonly type: "programming";
        readonly color: "#007800";
        readonly filenames: ["meson.build", "meson_options.txt"];
        readonly tmScope: "source.meson";
        readonly aceMode: "text";
        readonly languageId: 799141244;
    };
    readonly Metal: {
        readonly type: "programming";
        readonly color: "#8f14e9";
        readonly extensions: [".metal"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 230;
    };
    readonly 'Microsoft Developer Studio Project': {
        readonly type: "data";
        readonly extensions: [".dsp"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 800983837;
    };
    readonly 'Microsoft Visual Studio Solution': {
        readonly type: "data";
        readonly extensions: [".sln"];
        readonly tmScope: "source.solution";
        readonly aceMode: "text";
        readonly languageId: 849523096;
    };
    readonly MiniD: {
        readonly type: "programming";
        readonly extensions: [".minid"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 231;
    };
    readonly Mirah: {
        readonly type: "programming";
        readonly color: "#c7a938";
        readonly extensions: [".druby", ".duby", ".mirah"];
        readonly tmScope: "source.ruby";
        readonly aceMode: "ruby";
        readonly codemirrorMode: "ruby";
        readonly codemirrorMimeType: "text/x-ruby";
        readonly languageId: 232;
    };
    readonly Modelica: {
        readonly type: "programming";
        readonly color: "#de1d31";
        readonly extensions: [".mo"];
        readonly tmScope: "source.modelica";
        readonly aceMode: "text";
        readonly codemirrorMode: "modelica";
        readonly codemirrorMimeType: "text/x-modelica";
        readonly languageId: 233;
    };
    readonly 'Modula-2': {
        readonly type: "programming";
        readonly color: "#10253f";
        readonly extensions: [".mod"];
        readonly tmScope: "source.modula2";
        readonly aceMode: "text";
        readonly languageId: 234;
    };
    readonly 'Modula-3': {
        readonly type: "programming";
        readonly extensions: [".i3", ".ig", ".m3", ".mg"];
        readonly color: "#223388";
        readonly aceMode: "text";
        readonly tmScope: "source.modula-3";
        readonly languageId: 564743864;
    };
    readonly 'Module Management System': {
        readonly type: "programming";
        readonly extensions: [".mms", ".mmk"];
        readonly filenames: ["descrip.mmk", "descrip.mms"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 235;
    };
    readonly Monkey: {
        readonly type: "programming";
        readonly extensions: [".monkey", ".monkey2"];
        readonly aceMode: "text";
        readonly tmScope: "source.monkey";
        readonly languageId: 236;
    };
    readonly Moocode: {
        readonly type: "programming";
        readonly extensions: [".moo"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 237;
    };
    readonly MoonScript: {
        readonly type: "programming";
        readonly color: "#ff4585";
        readonly extensions: [".moon"];
        readonly interpreters: ["moon"];
        readonly tmScope: "source.moonscript";
        readonly aceMode: "text";
        readonly languageId: 238;
    };
    readonly 'Motorola 68K Assembly': {
        readonly type: "programming";
        readonly color: "#005daa";
        readonly group: "Assembly";
        readonly aliases: ["m68k"];
        readonly extensions: [".asm", ".i", ".inc", ".s", ".x68"];
        readonly tmScope: "source.m68k";
        readonly aceMode: "assembly_x86";
        readonly languageId: 477582706;
    };
    readonly Muse: {
        readonly type: "prose";
        readonly extensions: [".muse"];
        readonly tmScope: "text.muse";
        readonly aceMode: "text";
        readonly wrap: true;
        readonly languageId: 474864066;
        readonly aliases: ["amusewiki", "emacs muse"];
    };
    readonly Mustache: {
        readonly type: "markup";
        readonly color: "#724b3b";
        readonly extensions: [".mustache"];
        readonly tmScope: "text.html.smarty";
        readonly aceMode: "smarty";
        readonly codemirrorMode: "smarty";
        readonly codemirrorMimeType: "text/x-smarty";
        readonly languageId: 638334590;
    };
    readonly Myghty: {
        readonly type: "programming";
        readonly extensions: [".myt"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 239;
    };
    readonly NASL: {
        readonly type: "programming";
        readonly extensions: [".nasl", ".inc"];
        readonly tmScope: "source.nasl";
        readonly aceMode: "text";
        readonly languageId: 171666519;
    };
    readonly NCL: {
        readonly type: "programming";
        readonly color: "#28431f";
        readonly extensions: [".ncl"];
        readonly tmScope: "source.ncl";
        readonly aceMode: "text";
        readonly languageId: 240;
    };
    readonly NEON: {
        readonly type: "data";
        readonly extensions: [".neon"];
        readonly tmScope: "source.neon";
        readonly aceMode: "text";
        readonly aliases: ["nette object notation", "ne-on"];
        readonly languageId: 481192983;
    };
    readonly NL: {
        readonly type: "data";
        readonly extensions: [".nl"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 241;
    };
    readonly 'NPM Config': {
        readonly type: "data";
        readonly color: "#cb3837";
        readonly group: "INI";
        readonly aliases: ["npmrc"];
        readonly filenames: [".npmrc"];
        readonly tmScope: "source.ini.npmrc";
        readonly aceMode: "text";
        readonly languageId: 685022663;
    };
    readonly NSIS: {
        readonly type: "programming";
        readonly extensions: [".nsi", ".nsh"];
        readonly tmScope: "source.nsis";
        readonly aceMode: "text";
        readonly codemirrorMode: "nsis";
        readonly codemirrorMimeType: "text/x-nsis";
        readonly languageId: 242;
    };
    readonly NWScript: {
        readonly type: "programming";
        readonly color: "#111522";
        readonly extensions: [".nss"];
        readonly tmScope: "source.c.nwscript";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 731233819;
    };
    readonly Nearley: {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly color: "#990000";
        readonly extensions: [".ne", ".nearley"];
        readonly tmScope: "source.ne";
        readonly languageId: 521429430;
    };
    readonly Nemerle: {
        readonly type: "programming";
        readonly color: "#3d3c6e";
        readonly extensions: [".n"];
        readonly tmScope: "source.nemerle";
        readonly aceMode: "text";
        readonly languageId: 243;
    };
    readonly NetLinx: {
        readonly type: "programming";
        readonly color: "#0aa0ff";
        readonly extensions: [".axs", ".axi"];
        readonly tmScope: "source.netlinx";
        readonly aceMode: "text";
        readonly languageId: 244;
    };
    readonly 'NetLinx+ERB': {
        readonly type: "programming";
        readonly color: "#747faa";
        readonly extensions: [".axs.erb", ".axi.erb"];
        readonly tmScope: "source.netlinx.erb";
        readonly aceMode: "text";
        readonly languageId: 245;
    };
    readonly NetLogo: {
        readonly type: "programming";
        readonly color: "#ff6375";
        readonly extensions: [".nlogo"];
        readonly tmScope: "source.lisp";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 246;
    };
    readonly NewLisp: {
        readonly type: "programming";
        readonly color: "#87AED7";
        readonly extensions: [".nl", ".lisp", ".lsp"];
        readonly interpreters: ["newlisp"];
        readonly tmScope: "source.lisp";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 247;
    };
    readonly Nextflow: {
        readonly type: "programming";
        readonly aceMode: "groovy";
        readonly tmScope: "source.nextflow";
        readonly color: "#3ac486";
        readonly extensions: [".nf"];
        readonly filenames: ["nextflow.config"];
        readonly interpreters: ["nextflow"];
        readonly languageId: 506780613;
    };
    readonly Nginx: {
        readonly type: "data";
        readonly color: "#009639";
        readonly extensions: [".nginx", ".nginxconf", ".vhost"];
        readonly filenames: ["nginx.conf"];
        readonly tmScope: "source.nginx";
        readonly aliases: ["nginx configuration file"];
        readonly aceMode: "text";
        readonly codemirrorMode: "nginx";
        readonly codemirrorMimeType: "text/x-nginx-conf";
        readonly languageId: 248;
    };
    readonly Nim: {
        readonly type: "programming";
        readonly color: "#ffc200";
        readonly extensions: [".nim", ".nim.cfg", ".nimble", ".nimrod", ".nims"];
        readonly filenames: ["nim.cfg"];
        readonly aceMode: "text";
        readonly tmScope: "source.nim";
        readonly languageId: 249;
    };
    readonly Ninja: {
        readonly type: "data";
        readonly tmScope: "source.ninja";
        readonly extensions: [".ninja"];
        readonly aceMode: "text";
        readonly languageId: 250;
    };
    readonly Nit: {
        readonly type: "programming";
        readonly color: "#009917";
        readonly extensions: [".nit"];
        readonly tmScope: "source.nit";
        readonly aceMode: "text";
        readonly languageId: 251;
    };
    readonly Nix: {
        readonly type: "programming";
        readonly color: "#7e7eff";
        readonly extensions: [".nix"];
        readonly aliases: ["nixos"];
        readonly tmScope: "source.nix";
        readonly aceMode: "nix";
        readonly languageId: 252;
    };
    readonly Nu: {
        readonly type: "programming";
        readonly color: "#c9df40";
        readonly aliases: ["nush"];
        readonly extensions: [".nu"];
        readonly filenames: ["Nukefile"];
        readonly tmScope: "source.nu";
        readonly aceMode: "scheme";
        readonly codemirrorMode: "scheme";
        readonly codemirrorMimeType: "text/x-scheme";
        readonly interpreters: ["nush"];
        readonly languageId: 253;
    };
    readonly NumPy: {
        readonly type: "programming";
        readonly color: "#9C8AF9";
        readonly group: "Python";
        readonly extensions: [".numpy", ".numpyw", ".numsc"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly languageId: 254;
    };
    readonly Nunjucks: {
        readonly type: "markup";
        readonly color: "#3d8137";
        readonly extensions: [".njk"];
        readonly aliases: ["njk"];
        readonly tmScope: "text.html.nunjucks";
        readonly aceMode: "nunjucks";
        readonly languageId: 461856962;
    };
    readonly OCaml: {
        readonly type: "programming";
        readonly aceMode: "ocaml";
        readonly codemirrorMode: "mllike";
        readonly codemirrorMimeType: "text/x-ocaml";
        readonly color: "#3be133";
        readonly extensions: [".ml", ".eliom", ".eliomi", ".ml4", ".mli", ".mll", ".mly"];
        readonly interpreters: ["ocaml", "ocamlrun", "ocamlscript"];
        readonly tmScope: "source.ocaml";
        readonly languageId: 255;
    };
    readonly ObjDump: {
        readonly type: "data";
        readonly extensions: [".objdump"];
        readonly tmScope: "objdump.x86asm";
        readonly aceMode: "assembly_x86";
        readonly languageId: 256;
    };
    readonly 'Object Data Instance Notation': {
        readonly type: "data";
        readonly extensions: [".odin"];
        readonly tmScope: "source.odin-ehr";
        readonly aceMode: "text";
        readonly languageId: 985227236;
    };
    readonly ObjectScript: {
        readonly type: "programming";
        readonly extensions: [".cls"];
        readonly languageId: 202735509;
        readonly tmScope: "source.objectscript";
        readonly color: "#424893";
        readonly aceMode: "text";
    };
    readonly 'Objective-C': {
        readonly type: "programming";
        readonly tmScope: "source.objc";
        readonly color: "#438eff";
        readonly aliases: ["obj-c", "objc", "objectivec"];
        readonly extensions: [".m", ".h"];
        readonly aceMode: "objectivec";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-objectivec";
        readonly languageId: 257;
    };
    readonly 'Objective-C++': {
        readonly type: "programming";
        readonly tmScope: "source.objc++";
        readonly color: "#6866fb";
        readonly aliases: ["obj-c++", "objc++", "objectivec++"];
        readonly extensions: [".mm"];
        readonly aceMode: "objectivec";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-objectivec";
        readonly languageId: 258;
    };
    readonly 'Objective-J': {
        readonly type: "programming";
        readonly color: "#ff0c5a";
        readonly aliases: ["obj-j", "objectivej", "objj"];
        readonly extensions: [".j", ".sj"];
        readonly tmScope: "source.js.objj";
        readonly aceMode: "text";
        readonly languageId: 259;
    };
    readonly Odin: {
        readonly type: "programming";
        readonly color: "#60AFFE";
        readonly aliases: ["odinlang", "odin-lang"];
        readonly extensions: [".odin"];
        readonly tmScope: "source.odin";
        readonly aceMode: "text";
        readonly languageId: 889244082;
    };
    readonly Omgrofl: {
        readonly type: "programming";
        readonly extensions: [".omgrofl"];
        readonly color: "#cabbff";
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 260;
    };
    readonly Opa: {
        readonly type: "programming";
        readonly extensions: [".opa"];
        readonly tmScope: "source.opa";
        readonly aceMode: "text";
        readonly languageId: 261;
    };
    readonly Opal: {
        readonly type: "programming";
        readonly color: "#f7ede0";
        readonly extensions: [".opal"];
        readonly tmScope: "source.opal";
        readonly aceMode: "text";
        readonly languageId: 262;
    };
    readonly 'Open Policy Agent': {
        readonly type: "programming";
        readonly color: "#7d9199";
        readonly aceMode: "text";
        readonly extensions: [".rego"];
        readonly languageId: 840483232;
        readonly tmScope: "source.rego";
    };
    readonly OpenCL: {
        readonly type: "programming";
        readonly color: "#ed2e2d";
        readonly group: "C";
        readonly extensions: [".cl", ".opencl"];
        readonly tmScope: "source.c";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 263;
    };
    readonly 'OpenEdge ABL': {
        readonly type: "programming";
        readonly color: "#5ce600";
        readonly aliases: ["progress", "openedge", "abl"];
        readonly extensions: [".p", ".cls", ".w"];
        readonly tmScope: "source.abl";
        readonly aceMode: "text";
        readonly languageId: 264;
    };
    readonly OpenQASM: {
        readonly type: "programming";
        readonly extensions: [".qasm"];
        readonly color: "#AA70FF";
        readonly tmScope: "source.qasm";
        readonly aceMode: "text";
        readonly languageId: 153739399;
    };
    readonly 'OpenRC runscript': {
        readonly type: "programming";
        readonly group: "Shell";
        readonly aliases: ["openrc"];
        readonly interpreters: ["openrc-run"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 265;
    };
    readonly OpenSCAD: {
        readonly type: "programming";
        readonly color: "#e5cd45";
        readonly extensions: [".scad"];
        readonly tmScope: "source.scad";
        readonly aceMode: "scad";
        readonly languageId: 266;
    };
    readonly 'OpenStep Property List': {
        readonly type: "data";
        readonly extensions: [".plist", ".glyphs"];
        readonly tmScope: "source.plist";
        readonly aceMode: "text";
        readonly languageId: 598917541;
    };
    readonly 'OpenType Feature File': {
        readonly type: "data";
        readonly aliases: ["AFDKO"];
        readonly extensions: [".fea"];
        readonly tmScope: "source.opentype";
        readonly aceMode: "text";
        readonly languageId: 374317347;
    };
    readonly Org: {
        readonly type: "prose";
        readonly color: "#77aa99";
        readonly wrap: true;
        readonly extensions: [".org"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 267;
    };
    readonly Ox: {
        readonly type: "programming";
        readonly extensions: [".ox", ".oxh", ".oxo"];
        readonly tmScope: "source.ox";
        readonly aceMode: "text";
        readonly languageId: 268;
    };
    readonly Oxygene: {
        readonly type: "programming";
        readonly color: "#cdd0e3";
        readonly extensions: [".oxygene"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 269;
    };
    readonly Oz: {
        readonly type: "programming";
        readonly color: "#fab738";
        readonly extensions: [".oz"];
        readonly tmScope: "source.oz";
        readonly aceMode: "text";
        readonly codemirrorMode: "oz";
        readonly codemirrorMimeType: "text/x-oz";
        readonly languageId: 270;
    };
    readonly P4: {
        readonly type: "programming";
        readonly color: "#7055b5";
        readonly extensions: [".p4"];
        readonly tmScope: "source.p4";
        readonly aceMode: "text";
        readonly languageId: 348895984;
    };
    readonly 'PEG.js': {
        readonly type: "programming";
        readonly color: "#234d6b";
        readonly extensions: [".pegjs"];
        readonly tmScope: "source.pegjs";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "text/javascript";
        readonly languageId: 81442128;
    };
    readonly PHP: {
        readonly type: "programming";
        readonly tmScope: "text.html.php";
        readonly aceMode: "php";
        readonly codemirrorMode: "php";
        readonly codemirrorMimeType: "application/x-httpd-php";
        readonly color: "#4F5D95";
        readonly extensions: [".php", ".aw", ".ctp", ".fcgi", ".inc", ".php3", ".php4", ".php5", ".phps", ".phpt"];
        readonly filenames: [".php", ".php_cs", ".php_cs.dist", "Phakefile"];
        readonly interpreters: ["php"];
        readonly aliases: ["inc"];
        readonly languageId: 272;
    };
    readonly PLSQL: {
        readonly type: "programming";
        readonly aceMode: "sql";
        readonly codemirrorMode: "sql";
        readonly codemirrorMimeType: "text/x-plsql";
        readonly tmScope: "none";
        readonly color: "#dad8d8";
        readonly extensions: [".pls", ".bdy", ".ddl", ".fnc", ".pck", ".pkb", ".pks", ".plb", ".plsql", ".prc", ".spc", ".sql", ".tpb", ".tps", ".trg", ".vw"];
        readonly languageId: 273;
    };
    readonly PLpgSQL: {
        readonly type: "programming";
        readonly color: "#336790";
        readonly aceMode: "pgsql";
        readonly codemirrorMode: "sql";
        readonly codemirrorMimeType: "text/x-sql";
        readonly tmScope: "source.sql";
        readonly extensions: [".pgsql", ".sql"];
        readonly languageId: 274;
    };
    readonly 'POV-Ray SDL': {
        readonly type: "programming";
        readonly color: "#6bac65";
        readonly aliases: ["pov-ray", "povray"];
        readonly extensions: [".pov", ".inc"];
        readonly tmScope: "source.pov-ray sdl";
        readonly aceMode: "text";
        readonly languageId: 275;
    };
    readonly Pan: {
        readonly type: "programming";
        readonly color: "#cc0000";
        readonly extensions: [".pan"];
        readonly tmScope: "source.pan";
        readonly aceMode: "text";
        readonly languageId: 276;
    };
    readonly Papyrus: {
        readonly type: "programming";
        readonly color: "#6600cc";
        readonly extensions: [".psc"];
        readonly tmScope: "source.papyrus.skyrim";
        readonly aceMode: "text";
        readonly languageId: 277;
    };
    readonly Parrot: {
        readonly type: "programming";
        readonly color: "#f3ca0a";
        readonly extensions: [".parrot"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 278;
    };
    readonly 'Parrot Assembly': {
        readonly group: "Parrot";
        readonly type: "programming";
        readonly aliases: ["pasm"];
        readonly extensions: [".pasm"];
        readonly interpreters: ["parrot"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 279;
    };
    readonly 'Parrot Internal Representation': {
        readonly group: "Parrot";
        readonly tmScope: "source.parrot.pir";
        readonly type: "programming";
        readonly aliases: ["pir"];
        readonly extensions: [".pir"];
        readonly interpreters: ["parrot"];
        readonly aceMode: "text";
        readonly languageId: 280;
    };
    readonly Pascal: {
        readonly type: "programming";
        readonly color: "#E3F171";
        readonly aliases: ["delphi", "objectpascal"];
        readonly extensions: [".pas", ".dfm", ".dpr", ".inc", ".lpr", ".pascal", ".pp"];
        readonly interpreters: ["instantfpc"];
        readonly tmScope: "source.pascal";
        readonly aceMode: "pascal";
        readonly codemirrorMode: "pascal";
        readonly codemirrorMimeType: "text/x-pascal";
        readonly languageId: 281;
    };
    readonly Pawn: {
        readonly type: "programming";
        readonly color: "#dbb284";
        readonly extensions: [".pwn", ".inc", ".sma"];
        readonly tmScope: "source.pawn";
        readonly aceMode: "text";
        readonly languageId: 271;
    };
    readonly Pep8: {
        readonly type: "programming";
        readonly color: "#C76F5B";
        readonly extensions: [".pep"];
        readonly aceMode: "text";
        readonly tmScope: "source.pep8";
        readonly languageId: 840372442;
    };
    readonly Perl: {
        readonly type: "programming";
        readonly tmScope: "source.perl";
        readonly aceMode: "perl";
        readonly codemirrorMode: "perl";
        readonly codemirrorMimeType: "text/x-perl";
        readonly color: "#0298c3";
        readonly extensions: [".pl", ".al", ".cgi", ".fcgi", ".perl", ".ph", ".plx", ".pm", ".psgi", ".t"];
        readonly filenames: ["Makefile.PL", "Rexfile", "ack", "cpanfile"];
        readonly interpreters: ["cperl", "perl"];
        readonly aliases: ["cperl"];
        readonly languageId: 282;
    };
    readonly Pic: {
        readonly type: "markup";
        readonly group: "Roff";
        readonly tmScope: "source.pic";
        readonly extensions: [".pic", ".chem"];
        readonly aceMode: "text";
        readonly codemirrorMode: "troff";
        readonly codemirrorMimeType: "text/troff";
        readonly languageId: 425;
    };
    readonly Pickle: {
        readonly type: "data";
        readonly extensions: [".pkl"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 284;
    };
    readonly PicoLisp: {
        readonly type: "programming";
        readonly color: "#6067af";
        readonly extensions: [".l"];
        readonly interpreters: ["picolisp", "pil"];
        readonly tmScope: "source.lisp";
        readonly aceMode: "lisp";
        readonly languageId: 285;
    };
    readonly PigLatin: {
        readonly type: "programming";
        readonly color: "#fcd7de";
        readonly extensions: [".pig"];
        readonly tmScope: "source.pig_latin";
        readonly aceMode: "text";
        readonly languageId: 286;
    };
    readonly Pike: {
        readonly type: "programming";
        readonly color: "#005390";
        readonly extensions: [".pike", ".pmod"];
        readonly interpreters: ["pike"];
        readonly tmScope: "source.pike";
        readonly aceMode: "text";
        readonly languageId: 287;
    };
    readonly PlantUML: {
        readonly type: "data";
        readonly extensions: [".puml", ".iuml", ".plantuml"];
        readonly tmScope: "source.wsd";
        readonly aceMode: "text";
        readonly languageId: 833504686;
    };
    readonly Pod: {
        readonly type: "prose";
        readonly aceMode: "perl";
        readonly codemirrorMode: "perl";
        readonly codemirrorMimeType: "text/x-perl";
        readonly wrap: true;
        readonly extensions: [".pod"];
        readonly interpreters: ["perl"];
        readonly tmScope: "none";
        readonly languageId: 288;
    };
    readonly 'Pod 6': {
        readonly type: "prose";
        readonly aceMode: "perl";
        readonly tmScope: "source.raku";
        readonly wrap: true;
        readonly extensions: [".pod", ".pod6"];
        readonly interpreters: ["perl6"];
        readonly languageId: 155357471;
    };
    readonly PogoScript: {
        readonly type: "programming";
        readonly color: "#d80074";
        readonly extensions: [".pogo"];
        readonly tmScope: "source.pogoscript";
        readonly aceMode: "text";
        readonly languageId: 289;
    };
    readonly Pony: {
        readonly type: "programming";
        readonly extensions: [".pony"];
        readonly tmScope: "source.pony";
        readonly aceMode: "text";
        readonly languageId: 290;
    };
    readonly PostCSS: {
        readonly type: "markup";
        readonly color: "#dc3a0c";
        readonly tmScope: "source.postcss";
        readonly group: "CSS";
        readonly extensions: [".pcss", ".postcss"];
        readonly aceMode: "text";
        readonly languageId: 262764437;
    };
    readonly PostScript: {
        readonly type: "markup";
        readonly color: "#da291c";
        readonly extensions: [".ps", ".eps", ".epsi", ".pfa"];
        readonly tmScope: "source.postscript";
        readonly aliases: ["postscr"];
        readonly aceMode: "text";
        readonly languageId: 291;
    };
    readonly PowerBuilder: {
        readonly type: "programming";
        readonly color: "#8f0f8d";
        readonly extensions: [".pbt", ".sra", ".sru", ".srw"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 292;
    };
    readonly PowerShell: {
        readonly type: "programming";
        readonly color: "#012456";
        readonly tmScope: "source.powershell";
        readonly aceMode: "powershell";
        readonly codemirrorMode: "powershell";
        readonly codemirrorMimeType: "application/x-powershell";
        readonly aliases: ["posh", "pwsh"];
        readonly extensions: [".ps1", ".psd1", ".psm1"];
        readonly interpreters: ["pwsh"];
        readonly languageId: 293;
    };
    readonly Prisma: {
        readonly type: "data";
        readonly color: "#0c344b";
        readonly extensions: [".prisma"];
        readonly tmScope: "source.prisma";
        readonly aceMode: "text";
        readonly languageId: 499933428;
    };
    readonly Processing: {
        readonly type: "programming";
        readonly color: "#0096D8";
        readonly extensions: [".pde"];
        readonly tmScope: "source.processing";
        readonly aceMode: "text";
        readonly languageId: 294;
    };
    readonly Proguard: {
        readonly type: "data";
        readonly extensions: [".pro"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 716513858;
    };
    readonly Prolog: {
        readonly type: "programming";
        readonly color: "#74283c";
        readonly extensions: [".pl", ".pro", ".prolog", ".yap"];
        readonly interpreters: ["swipl", "yap"];
        readonly tmScope: "source.prolog";
        readonly aceMode: "prolog";
        readonly languageId: 295;
    };
    readonly 'Propeller Spin': {
        readonly type: "programming";
        readonly color: "#7fa2a7";
        readonly extensions: [".spin"];
        readonly tmScope: "source.spin";
        readonly aceMode: "text";
        readonly languageId: 296;
    };
    readonly 'Protocol Buffer': {
        readonly type: "data";
        readonly aliases: ["protobuf", "Protocol Buffers"];
        readonly extensions: [".proto"];
        readonly tmScope: "source.proto";
        readonly aceMode: "protobuf";
        readonly codemirrorMode: "protobuf";
        readonly codemirrorMimeType: "text/x-protobuf";
        readonly languageId: 297;
    };
    readonly 'Public Key': {
        readonly type: "data";
        readonly extensions: [".asc", ".pub"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly codemirrorMode: "asciiarmor";
        readonly codemirrorMimeType: "application/pgp";
        readonly languageId: 298;
    };
    readonly Pug: {
        readonly type: "markup";
        readonly color: "#a86454";
        readonly extensions: [".jade", ".pug"];
        readonly tmScope: "text.jade";
        readonly aceMode: "jade";
        readonly codemirrorMode: "pug";
        readonly codemirrorMimeType: "text/x-pug";
        readonly languageId: 179;
    };
    readonly Puppet: {
        readonly type: "programming";
        readonly color: "#302B6D";
        readonly extensions: [".pp"];
        readonly filenames: ["Modulefile"];
        readonly aceMode: "text";
        readonly codemirrorMode: "puppet";
        readonly codemirrorMimeType: "text/x-puppet";
        readonly tmScope: "source.puppet";
        readonly languageId: 299;
    };
    readonly 'Pure Data': {
        readonly type: "data";
        readonly extensions: [".pd"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 300;
    };
    readonly PureBasic: {
        readonly type: "programming";
        readonly color: "#5a6986";
        readonly extensions: [".pb", ".pbi"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 301;
    };
    readonly PureScript: {
        readonly type: "programming";
        readonly color: "#1D222D";
        readonly extensions: [".purs"];
        readonly tmScope: "source.purescript";
        readonly aceMode: "haskell";
        readonly codemirrorMode: "haskell";
        readonly codemirrorMimeType: "text/x-haskell";
        readonly languageId: 302;
    };
    readonly Python: {
        readonly type: "programming";
        readonly tmScope: "source.python";
        readonly aceMode: "python";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly color: "#3572A5";
        readonly extensions: [".py", ".cgi", ".fcgi", ".gyp", ".gypi", ".lmi", ".py3", ".pyde", ".pyi", ".pyp", ".pyt", ".pyw", ".rpy", ".smk", ".spec", ".tac", ".wsgi", ".xpy"];
        readonly filenames: [".gclient", "DEPS", "SConscript", "SConstruct", "Snakefile", "wscript"];
        readonly interpreters: ["python", "python2", "python3"];
        readonly aliases: ["python3", "rusthon"];
        readonly languageId: 303;
    };
    readonly 'Python console': {
        readonly type: "programming";
        readonly color: "#3572A5";
        readonly group: "Python";
        readonly aliases: ["pycon"];
        readonly tmScope: "text.python.console";
        readonly aceMode: "text";
        readonly languageId: 428;
    };
    readonly 'Python traceback': {
        readonly type: "data";
        readonly color: "#3572A5";
        readonly group: "Python";
        readonly extensions: [".pytb"];
        readonly tmScope: "text.python.traceback";
        readonly aceMode: "text";
        readonly languageId: 304;
    };
    readonly 'Q#': {
        readonly type: "programming";
        readonly extensions: [".qs"];
        readonly aliases: ["qsharp"];
        readonly color: "#fed659";
        readonly aceMode: "text";
        readonly tmScope: "source.qsharp";
        readonly languageId: 697448245;
    };
    readonly QML: {
        readonly type: "programming";
        readonly color: "#44a51c";
        readonly extensions: [".qml", ".qbs"];
        readonly tmScope: "source.qml";
        readonly aceMode: "text";
        readonly languageId: 305;
    };
    readonly QMake: {
        readonly type: "programming";
        readonly extensions: [".pro", ".pri"];
        readonly interpreters: ["qmake"];
        readonly tmScope: "source.qmake";
        readonly aceMode: "text";
        readonly languageId: 306;
    };
    readonly 'Qt Script': {
        readonly type: "programming";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "text/javascript";
        readonly extensions: [".qs"];
        readonly filenames: ["installscript.qs", "toolchain_installscript.qs"];
        readonly color: "#00b841";
        readonly tmScope: "source.js";
        readonly languageId: 558193693;
    };
    readonly Quake: {
        readonly type: "programming";
        readonly filenames: ["m3makefile", "m3overrides"];
        readonly color: "#882233";
        readonly aceMode: "text";
        readonly tmScope: "source.quake";
        readonly languageId: 375265331;
    };
    readonly R: {
        readonly type: "programming";
        readonly color: "#198CE7";
        readonly aliases: ["R", "Rscript", "splus"];
        readonly extensions: [".r", ".rd", ".rsx"];
        readonly filenames: [".Rprofile", "expr-dist"];
        readonly interpreters: ["Rscript"];
        readonly tmScope: "source.r";
        readonly aceMode: "r";
        readonly codemirrorMode: "r";
        readonly codemirrorMimeType: "text/x-rsrc";
        readonly languageId: 307;
    };
    readonly RAML: {
        readonly type: "markup";
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly tmScope: "source.yaml";
        readonly color: "#77d9fb";
        readonly extensions: [".raml"];
        readonly languageId: 308;
    };
    readonly RDoc: {
        readonly type: "prose";
        readonly color: "#701516";
        readonly aceMode: "rdoc";
        readonly wrap: true;
        readonly extensions: [".rdoc"];
        readonly tmScope: "text.rdoc";
        readonly languageId: 309;
    };
    readonly REALbasic: {
        readonly type: "programming";
        readonly extensions: [".rbbas", ".rbfrm", ".rbmnu", ".rbres", ".rbtbar", ".rbuistate"];
        readonly tmScope: "source.vbnet";
        readonly aceMode: "text";
        readonly languageId: 310;
    };
    readonly REXX: {
        readonly type: "programming";
        readonly color: "#d90e09";
        readonly aliases: ["arexx"];
        readonly extensions: [".rexx", ".pprx", ".rex"];
        readonly interpreters: ["regina", "rexx"];
        readonly tmScope: "source.rexx";
        readonly aceMode: "text";
        readonly languageId: 311;
    };
    readonly RMarkdown: {
        readonly type: "prose";
        readonly color: "#198ce7";
        readonly wrap: true;
        readonly aceMode: "markdown";
        readonly codemirrorMode: "gfm";
        readonly codemirrorMimeType: "text/x-gfm";
        readonly extensions: [".rmd"];
        readonly tmScope: "source.gfm";
        readonly languageId: 313;
    };
    readonly RPC: {
        readonly type: "programming";
        readonly aliases: ["rpcgen", "oncrpc", "xdr"];
        readonly aceMode: "c_cpp";
        readonly extensions: [".x"];
        readonly tmScope: "source.c";
        readonly languageId: 1031374237;
    };
    readonly 'RPM Spec': {
        readonly type: "data";
        readonly tmScope: "source.rpm-spec";
        readonly extensions: [".spec"];
        readonly aliases: ["specfile"];
        readonly aceMode: "text";
        readonly codemirrorMode: "rpm";
        readonly codemirrorMimeType: "text/x-rpm-spec";
        readonly languageId: 314;
    };
    readonly RUNOFF: {
        readonly type: "markup";
        readonly color: "#665a4e";
        readonly extensions: [".rnh", ".rno"];
        readonly wrap: true;
        readonly tmScope: "text.runoff";
        readonly aceMode: "text";
        readonly languageId: 315;
    };
    readonly Racket: {
        readonly type: "programming";
        readonly color: "#3c5caa";
        readonly extensions: [".rkt", ".rktd", ".rktl", ".scrbl"];
        readonly interpreters: ["racket"];
        readonly tmScope: "source.racket";
        readonly aceMode: "lisp";
        readonly languageId: 316;
    };
    readonly Ragel: {
        readonly type: "programming";
        readonly color: "#9d5200";
        readonly extensions: [".rl"];
        readonly aliases: ["ragel-rb", "ragel-ruby"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 317;
    };
    readonly Raku: {
        readonly type: "programming";
        readonly color: "#0000fb";
        readonly extensions: [".6pl", ".6pm", ".nqp", ".p6", ".p6l", ".p6m", ".pl", ".pl6", ".pm", ".pm6", ".raku", ".rakumod", ".t"];
        readonly interpreters: ["perl6", "raku", "rakudo"];
        readonly aliases: ["perl6", "perl-6"];
        readonly tmScope: "source.raku";
        readonly aceMode: "perl";
        readonly codemirrorMode: "perl";
        readonly codemirrorMimeType: "text/x-perl";
        readonly languageId: 283;
    };
    readonly Rascal: {
        readonly type: "programming";
        readonly color: "#fffaa0";
        readonly extensions: [".rsc"];
        readonly tmScope: "source.rascal";
        readonly aceMode: "text";
        readonly languageId: 173616037;
    };
    readonly 'Raw token data': {
        readonly type: "data";
        readonly aliases: ["raw"];
        readonly extensions: [".raw"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 318;
    };
    readonly ReScript: {
        readonly type: "programming";
        readonly color: "#ed5051";
        readonly aceMode: "rust";
        readonly codemirrorMode: "rust";
        readonly codemirrorMimeType: "text/x-rustsrc";
        readonly extensions: [".res"];
        readonly interpreters: ["ocaml"];
        readonly tmScope: "source.rescript";
        readonly languageId: 501875647;
    };
    readonly 'Readline Config': {
        readonly type: "data";
        readonly group: "INI";
        readonly aliases: ["inputrc", "readline"];
        readonly filenames: [".inputrc", "inputrc"];
        readonly tmScope: "source.inputrc";
        readonly aceMode: "text";
        readonly languageId: 538732839;
    };
    readonly Reason: {
        readonly type: "programming";
        readonly color: "#ff5847";
        readonly aceMode: "rust";
        readonly codemirrorMode: "rust";
        readonly codemirrorMimeType: "text/x-rustsrc";
        readonly extensions: [".re", ".rei"];
        readonly tmScope: "source.reason";
        readonly languageId: 869538413;
    };
    readonly Rebol: {
        readonly type: "programming";
        readonly color: "#358a5b";
        readonly extensions: [".reb", ".r", ".r2", ".r3", ".rebol"];
        readonly aceMode: "text";
        readonly tmScope: "source.rebol";
        readonly languageId: 319;
    };
    readonly 'Record Jar': {
        readonly type: "data";
        readonly filenames: ["language-subtag-registry.txt"];
        readonly tmScope: "source.record-jar";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly aceMode: "text";
        readonly color: "#0673ba";
        readonly languageId: 865765202;
    };
    readonly Red: {
        readonly type: "programming";
        readonly color: "#f50000";
        readonly extensions: [".red", ".reds"];
        readonly aliases: ["red/system"];
        readonly tmScope: "source.red";
        readonly aceMode: "text";
        readonly languageId: 320;
    };
    readonly Redcode: {
        readonly type: "programming";
        readonly extensions: [".cw"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 321;
    };
    readonly 'Redirect Rules': {
        readonly type: "data";
        readonly aliases: ["redirects"];
        readonly filenames: ["_redirects"];
        readonly tmScope: "source.redirects";
        readonly aceMode: "text";
        readonly languageId: 1020148948;
    };
    readonly 'Regular Expression': {
        readonly type: "data";
        readonly color: "#009a00";
        readonly extensions: [".regexp", ".regex"];
        readonly aliases: ["regexp", "regex"];
        readonly aceMode: "text";
        readonly tmScope: "source.regexp";
        readonly languageId: 363378884;
    };
    readonly "Ren'Py": {
        readonly type: "programming";
        readonly aliases: ["renpy"];
        readonly color: "#ff7f7f";
        readonly extensions: [".rpy"];
        readonly tmScope: "source.renpy";
        readonly aceMode: "python";
        readonly languageId: 322;
    };
    readonly RenderScript: {
        readonly type: "programming";
        readonly extensions: [".rs", ".rsh"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 323;
    };
    readonly 'Rich Text Format': {
        readonly type: "markup";
        readonly extensions: [".rtf"];
        readonly tmScope: "text.rtf";
        readonly aceMode: "text";
        readonly languageId: 51601661;
    };
    readonly Ring: {
        readonly type: "programming";
        readonly color: "#2D54CB";
        readonly extensions: [".ring"];
        readonly tmScope: "source.ring";
        readonly aceMode: "text";
        readonly languageId: 431;
    };
    readonly Riot: {
        readonly type: "markup";
        readonly color: "#A71E49";
        readonly aceMode: "html";
        readonly extensions: [".riot"];
        readonly tmScope: "text.html.riot";
        readonly languageId: 878396783;
    };
    readonly RobotFramework: {
        readonly type: "programming";
        readonly color: "#00c0b5";
        readonly extensions: [".robot"];
        readonly tmScope: "text.robot";
        readonly aceMode: "text";
        readonly languageId: 324;
    };
    readonly Roff: {
        readonly type: "markup";
        readonly color: "#ecdebe";
        readonly extensions: [".roff", ".1", ".1in", ".1m", ".1x", ".2", ".3", ".3in", ".3m", ".3p", ".3pm", ".3qt", ".3x", ".4", ".5", ".6", ".7", ".8", ".9", ".l", ".man", ".mdoc", ".me", ".ms", ".n", ".nr", ".rno", ".tmac"];
        readonly filenames: ["eqnrc", "mmn", "mmt", "troffrc", "troffrc-end"];
        readonly tmScope: "text.roff";
        readonly aliases: ["groff", "man", "manpage", "man page", "man-page", "mdoc", "nroff", "troff"];
        readonly wrap: true;
        readonly aceMode: "text";
        readonly codemirrorMode: "troff";
        readonly codemirrorMimeType: "text/troff";
        readonly languageId: 141;
    };
    readonly 'Roff Manpage': {
        readonly type: "markup";
        readonly color: "#ecdebe";
        readonly group: "Roff";
        readonly extensions: [".1", ".1in", ".1m", ".1x", ".2", ".3", ".3in", ".3m", ".3p", ".3pm", ".3qt", ".3x", ".4", ".5", ".6", ".7", ".8", ".9", ".man", ".mdoc"];
        readonly wrap: true;
        readonly tmScope: "text.roff";
        readonly aceMode: "text";
        readonly codemirrorMode: "troff";
        readonly codemirrorMimeType: "text/troff";
        readonly languageId: 612669833;
    };
    readonly Rouge: {
        readonly type: "programming";
        readonly aceMode: "clojure";
        readonly codemirrorMode: "clojure";
        readonly codemirrorMimeType: "text/x-clojure";
        readonly color: "#cc0088";
        readonly extensions: [".rg"];
        readonly tmScope: "source.clojure";
        readonly languageId: 325;
    };
    readonly Ruby: {
        readonly type: "programming";
        readonly tmScope: "source.ruby";
        readonly aceMode: "ruby";
        readonly codemirrorMode: "ruby";
        readonly codemirrorMimeType: "text/x-ruby";
        readonly color: "#701516";
        readonly aliases: ["jruby", "macruby", "rake", "rb", "rbx"];
        readonly extensions: [".rb", ".builder", ".eye", ".fcgi", ".gemspec", ".god", ".jbuilder", ".mspec", ".pluginspec", ".podspec", ".prawn", ".rabl", ".rake", ".rbi", ".rbuild", ".rbw", ".rbx", ".ru", ".ruby", ".spec", ".thor", ".watchr"];
        readonly interpreters: ["ruby", "macruby", "rake", "jruby", "rbx"];
        readonly filenames: [".irbrc", ".pryrc", ".simplecov", "Appraisals", "Berksfile", "Brewfile", "Buildfile", "Capfile", "Dangerfile", "Deliverfile", "Fastfile", "Gemfile", "Guardfile", "Jarfile", "Mavenfile", "Podfile", "Puppetfile", "Rakefile", "Snapfile", "Thorfile", "Vagrantfile", "buildfile"];
        readonly languageId: 326;
    };
    readonly Rust: {
        readonly type: "programming";
        readonly aliases: ["rs"];
        readonly color: "#dea584";
        readonly extensions: [".rs", ".rs.in"];
        readonly tmScope: "source.rust";
        readonly aceMode: "rust";
        readonly codemirrorMode: "rust";
        readonly codemirrorMimeType: "text/x-rustsrc";
        readonly languageId: 327;
    };
    readonly SAS: {
        readonly type: "programming";
        readonly color: "#B34936";
        readonly extensions: [".sas"];
        readonly tmScope: "source.sas";
        readonly aceMode: "text";
        readonly codemirrorMode: "sas";
        readonly codemirrorMimeType: "text/x-sas";
        readonly languageId: 328;
    };
    readonly SCSS: {
        readonly type: "markup";
        readonly color: "#c6538c";
        readonly tmScope: "source.css.scss";
        readonly aceMode: "scss";
        readonly codemirrorMode: "css";
        readonly codemirrorMimeType: "text/x-scss";
        readonly extensions: [".scss"];
        readonly languageId: 329;
    };
    readonly 'SELinux Policy': {
        readonly aliases: ["SELinux Kernel Policy Language", "sepolicy"];
        readonly type: "data";
        readonly tmScope: "source.sepolicy";
        readonly extensions: [".te"];
        readonly filenames: ["file_contexts", "genfs_contexts", "initial_sids", "port_contexts", "security_classes"];
        readonly aceMode: "text";
        readonly languageId: 880010326;
    };
    readonly SMT: {
        readonly type: "programming";
        readonly extensions: [".smt2", ".smt"];
        readonly interpreters: ["boolector", "cvc4", "mathsat5", "opensmt", "smtinterpol", "smt-rat", "stp", "verit", "yices2", "z3"];
        readonly tmScope: "source.smt";
        readonly aceMode: "text";
        readonly languageId: 330;
    };
    readonly SPARQL: {
        readonly type: "data";
        readonly color: "#0C4597";
        readonly tmScope: "source.sparql";
        readonly aceMode: "text";
        readonly codemirrorMode: "sparql";
        readonly codemirrorMimeType: "application/sparql-query";
        readonly extensions: [".sparql", ".rq"];
        readonly languageId: 331;
    };
    readonly SQF: {
        readonly type: "programming";
        readonly color: "#3F3F3F";
        readonly extensions: [".sqf", ".hqf"];
        readonly tmScope: "source.sqf";
        readonly aceMode: "text";
        readonly languageId: 332;
    };
    readonly SQL: {
        readonly type: "data";
        readonly color: "#e38c00";
        readonly tmScope: "source.sql";
        readonly aceMode: "sql";
        readonly codemirrorMode: "sql";
        readonly codemirrorMimeType: "text/x-sql";
        readonly extensions: [".sql", ".cql", ".ddl", ".inc", ".mysql", ".prc", ".tab", ".udf", ".viw"];
        readonly languageId: 333;
    };
    readonly SQLPL: {
        readonly type: "programming";
        readonly color: "#e38c00";
        readonly aceMode: "sql";
        readonly codemirrorMode: "sql";
        readonly codemirrorMimeType: "text/x-sql";
        readonly tmScope: "source.sql";
        readonly extensions: [".sql", ".db2"];
        readonly languageId: 334;
    };
    readonly 'SRecode Template': {
        readonly type: "markup";
        readonly color: "#348a34";
        readonly tmScope: "source.lisp";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly extensions: [".srt"];
        readonly languageId: 335;
    };
    readonly 'SSH Config': {
        readonly type: "data";
        readonly group: "INI";
        readonly filenames: ["ssh-config", "ssh_config", "sshconfig", "sshconfig.snip", "sshd-config", "sshd_config"];
        readonly aceMode: "text";
        readonly tmScope: "source.ssh-config";
        readonly languageId: 554920715;
    };
    readonly STON: {
        readonly type: "data";
        readonly group: "Smalltalk";
        readonly extensions: [".ston"];
        readonly tmScope: "source.smalltalk";
        readonly aceMode: "text";
        readonly languageId: 336;
    };
    readonly SVG: {
        readonly type: "data";
        readonly color: "#ff9900";
        readonly extensions: [".svg"];
        readonly tmScope: "text.xml.svg";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 337;
    };
    readonly SWIG: {
        readonly type: "programming";
        readonly extensions: [".i"];
        readonly tmScope: "source.c++";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 1066250075;
    };
    readonly Sage: {
        readonly type: "programming";
        readonly extensions: [".sage", ".sagews"];
        readonly tmScope: "source.python";
        readonly aceMode: "python";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly languageId: 338;
    };
    readonly SaltStack: {
        readonly type: "programming";
        readonly color: "#646464";
        readonly aliases: ["saltstate", "salt"];
        readonly extensions: [".sls"];
        readonly tmScope: "source.yaml.salt";
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly languageId: 339;
    };
    readonly Sass: {
        readonly type: "markup";
        readonly color: "#a53b70";
        readonly tmScope: "source.sass";
        readonly extensions: [".sass"];
        readonly aceMode: "sass";
        readonly codemirrorMode: "sass";
        readonly codemirrorMimeType: "text/x-sass";
        readonly languageId: 340;
    };
    readonly Scala: {
        readonly type: "programming";
        readonly tmScope: "source.scala";
        readonly aceMode: "scala";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-scala";
        readonly color: "#c22d40";
        readonly extensions: [".scala", ".kojo", ".sbt", ".sc"];
        readonly interpreters: ["scala"];
        readonly languageId: 341;
    };
    readonly Scaml: {
        readonly type: "markup";
        readonly color: "#bd181a";
        readonly extensions: [".scaml"];
        readonly tmScope: "source.scaml";
        readonly aceMode: "text";
        readonly languageId: 342;
    };
    readonly Scheme: {
        readonly type: "programming";
        readonly color: "#1e4aec";
        readonly extensions: [".scm", ".sch", ".sld", ".sls", ".sps", ".ss"];
        readonly interpreters: ["scheme", "guile", "bigloo", "chicken", "csi", "gosh", "r6rs"];
        readonly tmScope: "source.scheme";
        readonly aceMode: "scheme";
        readonly codemirrorMode: "scheme";
        readonly codemirrorMimeType: "text/x-scheme";
        readonly languageId: 343;
    };
    readonly Scilab: {
        readonly type: "programming";
        readonly color: "#ca0f21";
        readonly extensions: [".sci", ".sce", ".tst"];
        readonly tmScope: "source.scilab";
        readonly aceMode: "text";
        readonly languageId: 344;
    };
    readonly Self: {
        readonly type: "programming";
        readonly color: "#0579aa";
        readonly extensions: [".self"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 345;
    };
    readonly ShaderLab: {
        readonly type: "programming";
        readonly color: "#222c37";
        readonly extensions: [".shader"];
        readonly aceMode: "text";
        readonly tmScope: "source.shaderlab";
        readonly languageId: 664257356;
    };
    readonly Shell: {
        readonly type: "programming";
        readonly color: "#89e051";
        readonly aliases: ["sh", "shell-script", "bash", "zsh"];
        readonly extensions: [".sh", ".bash", ".bats", ".cgi", ".command", ".env", ".fcgi", ".ksh", ".sh.in", ".tmux", ".tool", ".zsh"];
        readonly filenames: [".bash_aliases", ".bash_history", ".bash_logout", ".bash_profile", ".bashrc", ".cshrc", ".env", ".env.example", ".flaskenv", ".login", ".profile", ".zlogin", ".zlogout", ".zprofile", ".zshenv", ".zshrc", "9fs", "PKGBUILD", "bash_aliases", "bash_logout", "bash_profile", "bashrc", "cshrc", "gradlew", "login", "man", "profile", "zlogin", "zlogout", "zprofile", "zshenv", "zshrc"];
        readonly interpreters: ["ash", "bash", "dash", "ksh", "mksh", "pdksh", "rc", "sh", "zsh"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 346;
    };
    readonly ShellSession: {
        readonly type: "programming";
        readonly extensions: [".sh-session"];
        readonly aliases: ["bash session", "console"];
        readonly tmScope: "text.shell-session";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 347;
    };
    readonly Shen: {
        readonly type: "programming";
        readonly color: "#120F14";
        readonly extensions: [".shen"];
        readonly tmScope: "source.shen";
        readonly aceMode: "text";
        readonly languageId: 348;
    };
    readonly Sieve: {
        readonly type: "programming";
        readonly tmScope: "source.sieve";
        readonly aceMode: "text";
        readonly extensions: [".sieve"];
        readonly codemirrorMode: "sieve";
        readonly codemirrorMimeType: "application/sieve";
        readonly languageId: 208976687;
    };
    readonly Singularity: {
        readonly type: "programming";
        readonly color: "#64E6AD";
        readonly tmScope: "source.singularity";
        readonly filenames: ["Singularity"];
        readonly aceMode: "text";
        readonly languageId: 987024632;
    };
    readonly Slash: {
        readonly type: "programming";
        readonly color: "#007eff";
        readonly extensions: [".sl"];
        readonly tmScope: "text.html.slash";
        readonly aceMode: "text";
        readonly languageId: 349;
    };
    readonly Slice: {
        readonly type: "programming";
        readonly color: "#003fa2";
        readonly tmScope: "source.slice";
        readonly aceMode: "text";
        readonly extensions: [".ice"];
        readonly languageId: 894641667;
    };
    readonly Slim: {
        readonly type: "markup";
        readonly color: "#2b2b2b";
        readonly extensions: [".slim"];
        readonly tmScope: "text.slim";
        readonly aceMode: "text";
        readonly codemirrorMode: "slim";
        readonly codemirrorMimeType: "text/x-slim";
        readonly languageId: 350;
    };
    readonly SmPL: {
        readonly type: "programming";
        readonly extensions: [".cocci"];
        readonly aliases: ["coccinelle"];
        readonly aceMode: "text";
        readonly tmScope: "source.smpl";
        readonly color: "#c94949";
        readonly languageId: 164123055;
    };
    readonly Smali: {
        readonly type: "programming";
        readonly extensions: [".smali"];
        readonly aceMode: "text";
        readonly tmScope: "source.smali";
        readonly languageId: 351;
    };
    readonly Smalltalk: {
        readonly type: "programming";
        readonly color: "#596706";
        readonly extensions: [".st", ".cs"];
        readonly aliases: ["squeak"];
        readonly tmScope: "source.smalltalk";
        readonly aceMode: "text";
        readonly codemirrorMode: "smalltalk";
        readonly codemirrorMimeType: "text/x-stsrc";
        readonly languageId: 352;
    };
    readonly Smarty: {
        readonly type: "programming";
        readonly color: "#f0c040";
        readonly extensions: [".tpl"];
        readonly aceMode: "smarty";
        readonly codemirrorMode: "smarty";
        readonly codemirrorMimeType: "text/x-smarty";
        readonly tmScope: "text.html.smarty";
        readonly languageId: 353;
    };
    readonly Solidity: {
        readonly type: "programming";
        readonly color: "#AA6746";
        readonly aceMode: "text";
        readonly tmScope: "source.solidity";
        readonly extensions: [".sol"];
        readonly languageId: 237469032;
    };
    readonly Soong: {
        readonly type: "data";
        readonly tmScope: "source.bp";
        readonly aceMode: "text";
        readonly filenames: ["Android.bp"];
        readonly languageId: 222900098;
    };
    readonly SourcePawn: {
        readonly type: "programming";
        readonly color: "#f69e1d";
        readonly aliases: ["sourcemod"];
        readonly extensions: [".sp", ".inc"];
        readonly tmScope: "source.sourcepawn";
        readonly aceMode: "text";
        readonly languageId: 354;
    };
    readonly 'Spline Font Database': {
        readonly type: "data";
        readonly extensions: [".sfd"];
        readonly tmScope: "text.sfd";
        readonly aceMode: "yaml";
        readonly languageId: 767169629;
    };
    readonly Squirrel: {
        readonly type: "programming";
        readonly color: "#800000";
        readonly extensions: [".nut"];
        readonly tmScope: "source.nut";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-c++src";
        readonly languageId: 355;
    };
    readonly Stan: {
        readonly type: "programming";
        readonly color: "#b2011d";
        readonly extensions: [".stan"];
        readonly aceMode: "text";
        readonly tmScope: "source.stan";
        readonly languageId: 356;
    };
    readonly 'Standard ML': {
        readonly type: "programming";
        readonly color: "#dc566d";
        readonly aliases: ["sml"];
        readonly extensions: [".ml", ".fun", ".sig", ".sml"];
        readonly tmScope: "source.ml";
        readonly aceMode: "text";
        readonly codemirrorMode: "mllike";
        readonly codemirrorMimeType: "text/x-ocaml";
        readonly languageId: 357;
    };
    readonly Starlark: {
        readonly type: "programming";
        readonly tmScope: "source.python";
        readonly aceMode: "python";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly color: "#76d275";
        readonly extensions: [".bzl"];
        readonly filenames: ["BUCK", "BUILD", "BUILD.bazel", "Tiltfile", "WORKSPACE"];
        readonly aliases: ["bazel", "bzl"];
        readonly languageId: 960266174;
    };
    readonly Stata: {
        readonly type: "programming";
        readonly color: "#1a5f91";
        readonly extensions: [".do", ".ado", ".doh", ".ihlp", ".mata", ".matah", ".sthlp"];
        readonly tmScope: "source.stata";
        readonly aceMode: "text";
        readonly languageId: 358;
    };
    readonly StringTemplate: {
        readonly type: "markup";
        readonly color: "#3fb34f";
        readonly extensions: [".st"];
        readonly tmScope: "source.string-template";
        readonly aceMode: "html";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly languageId: 89855901;
    };
    readonly Stylus: {
        readonly type: "markup";
        readonly color: "#ff6347";
        readonly extensions: [".styl"];
        readonly tmScope: "source.stylus";
        readonly aceMode: "stylus";
        readonly languageId: 359;
    };
    readonly 'SubRip Text': {
        readonly type: "data";
        readonly color: "#9e0101";
        readonly extensions: [".srt"];
        readonly aceMode: "text";
        readonly tmScope: "text.srt";
        readonly languageId: 360;
    };
    readonly SugarSS: {
        readonly type: "markup";
        readonly color: "#2fcc9f";
        readonly tmScope: "source.css.postcss.sugarss";
        readonly group: "CSS";
        readonly extensions: [".sss"];
        readonly aceMode: "text";
        readonly languageId: 826404698;
    };
    readonly SuperCollider: {
        readonly type: "programming";
        readonly color: "#46390b";
        readonly extensions: [".sc", ".scd"];
        readonly interpreters: ["sclang", "scsynth"];
        readonly tmScope: "source.supercollider";
        readonly aceMode: "text";
        readonly languageId: 361;
    };
    readonly Svelte: {
        readonly type: "markup";
        readonly color: "#ff3e00";
        readonly tmScope: "source.svelte";
        readonly aceMode: "html";
        readonly codemirrorMode: "htmlmixed";
        readonly codemirrorMimeType: "text/html";
        readonly extensions: [".svelte"];
        readonly languageId: 928734530;
    };
    readonly Swift: {
        readonly type: "programming";
        readonly color: "#F05138";
        readonly extensions: [".swift"];
        readonly tmScope: "source.swift";
        readonly aceMode: "text";
        readonly codemirrorMode: "swift";
        readonly codemirrorMimeType: "text/x-swift";
        readonly languageId: 362;
    };
    readonly SystemVerilog: {
        readonly type: "programming";
        readonly color: "#DAE1C2";
        readonly extensions: [".sv", ".svh", ".vh"];
        readonly tmScope: "source.systemverilog";
        readonly aceMode: "verilog";
        readonly codemirrorMode: "verilog";
        readonly codemirrorMimeType: "text/x-systemverilog";
        readonly languageId: 363;
    };
    readonly 'TI Program': {
        readonly type: "programming";
        readonly aceMode: "text";
        readonly color: "#A0AA87";
        readonly extensions: [".8xp", ".8xk", ".8xk.txt", ".8xp.txt"];
        readonly languageId: 422;
        readonly tmScope: "none";
    };
    readonly TLA: {
        readonly type: "programming";
        readonly color: "#4b0079";
        readonly extensions: [".tla"];
        readonly tmScope: "source.tla";
        readonly aceMode: "text";
        readonly languageId: 364;
    };
    readonly TOML: {
        readonly type: "data";
        readonly color: "#9c4221";
        readonly extensions: [".toml"];
        readonly filenames: ["Cargo.lock", "Gopkg.lock", "Pipfile", "poetry.lock"];
        readonly tmScope: "source.toml";
        readonly aceMode: "toml";
        readonly codemirrorMode: "toml";
        readonly codemirrorMimeType: "text/x-toml";
        readonly languageId: 365;
    };
    readonly TSQL: {
        readonly type: "programming";
        readonly color: "#e38c00";
        readonly extensions: [".sql"];
        readonly aceMode: "sql";
        readonly tmScope: "source.tsql";
        readonly languageId: 918334941;
    };
    readonly TSV: {
        readonly type: "data";
        readonly color: "#237346";
        readonly aceMode: "text";
        readonly tmScope: "source.generic-db";
        readonly extensions: [".tsv"];
        readonly languageId: 1035892117;
    };
    readonly TSX: {
        readonly type: "programming";
        readonly color: "#2b7489";
        readonly group: "TypeScript";
        readonly extensions: [".tsx"];
        readonly tmScope: "source.tsx";
        readonly aceMode: "javascript";
        readonly codemirrorMode: "jsx";
        readonly codemirrorMimeType: "text/jsx";
        readonly languageId: 94901924;
    };
    readonly TXL: {
        readonly type: "programming";
        readonly color: "#0178b8";
        readonly extensions: [".txl"];
        readonly tmScope: "source.txl";
        readonly aceMode: "text";
        readonly languageId: 366;
    };
    readonly Tcl: {
        readonly type: "programming";
        readonly color: "#e4cc98";
        readonly extensions: [".tcl", ".adp", ".tcl.in", ".tm"];
        readonly filenames: ["owh", "starfield"];
        readonly interpreters: ["tclsh", "wish"];
        readonly tmScope: "source.tcl";
        readonly aceMode: "tcl";
        readonly codemirrorMode: "tcl";
        readonly codemirrorMimeType: "text/x-tcl";
        readonly languageId: 367;
    };
    readonly Tcsh: {
        readonly type: "programming";
        readonly group: "Shell";
        readonly extensions: [".tcsh", ".csh"];
        readonly interpreters: ["tcsh", "csh"];
        readonly tmScope: "source.shell";
        readonly aceMode: "sh";
        readonly codemirrorMode: "shell";
        readonly codemirrorMimeType: "text/x-sh";
        readonly languageId: 368;
    };
    readonly TeX: {
        readonly type: "markup";
        readonly color: "#3D6117";
        readonly aceMode: "tex";
        readonly codemirrorMode: "stex";
        readonly codemirrorMimeType: "text/x-stex";
        readonly tmScope: "text.tex.latex";
        readonly wrap: true;
        readonly aliases: ["latex"];
        readonly extensions: [".tex", ".aux", ".bbx", ".cbx", ".cls", ".dtx", ".ins", ".lbx", ".ltx", ".mkii", ".mkiv", ".mkvi", ".sty", ".toc"];
        readonly languageId: 369;
    };
    readonly Tea: {
        readonly type: "markup";
        readonly extensions: [".tea"];
        readonly tmScope: "source.tea";
        readonly aceMode: "text";
        readonly languageId: 370;
    };
    readonly Terra: {
        readonly type: "programming";
        readonly extensions: [".t"];
        readonly color: "#00004c";
        readonly tmScope: "source.terra";
        readonly aceMode: "lua";
        readonly codemirrorMode: "lua";
        readonly codemirrorMimeType: "text/x-lua";
        readonly interpreters: ["lua"];
        readonly languageId: 371;
    };
    readonly Texinfo: {
        readonly type: "prose";
        readonly wrap: true;
        readonly extensions: [".texinfo", ".texi", ".txi"];
        readonly aceMode: "text";
        readonly tmScope: "text.texinfo";
        readonly interpreters: ["makeinfo"];
        readonly languageId: 988020015;
    };
    readonly Text: {
        readonly type: "prose";
        readonly wrap: true;
        readonly aliases: ["fundamental", "plain text"];
        readonly extensions: [".txt", ".fr", ".nb", ".ncl", ".no"];
        readonly filenames: ["COPYING", "COPYING.regex", "COPYRIGHT.regex", "FONTLOG", "INSTALL", "INSTALL.mysql", "LICENSE", "LICENSE.mysql", "NEWS", "README.me", "README.mysql", "README.nss", "click.me", "delete.me", "keep.me", "package.mask", "package.use.mask", "package.use.stable.mask", "read.me", "readme.1st", "test.me", "use.mask", "use.stable.mask"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 372;
    };
    readonly 'TextMate Properties': {
        readonly type: "data";
        readonly color: "#df66e4";
        readonly aliases: ["tm-properties"];
        readonly filenames: [".tm_properties"];
        readonly aceMode: "properties";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly tmScope: "source.tm-properties";
        readonly languageId: 981795023;
    };
    readonly Textile: {
        readonly type: "prose";
        readonly color: "#ffe7ac";
        readonly aceMode: "textile";
        readonly codemirrorMode: "textile";
        readonly codemirrorMimeType: "text/x-textile";
        readonly wrap: true;
        readonly extensions: [".textile"];
        readonly tmScope: "none";
        readonly languageId: 373;
    };
    readonly Thrift: {
        readonly type: "programming";
        readonly color: "#D12127";
        readonly tmScope: "source.thrift";
        readonly extensions: [".thrift"];
        readonly aceMode: "text";
        readonly languageId: 374;
    };
    readonly Turing: {
        readonly type: "programming";
        readonly color: "#cf142b";
        readonly extensions: [".t", ".tu"];
        readonly tmScope: "source.turing";
        readonly aceMode: "text";
        readonly languageId: 375;
    };
    readonly Turtle: {
        readonly type: "data";
        readonly extensions: [".ttl"];
        readonly tmScope: "source.turtle";
        readonly aceMode: "text";
        readonly codemirrorMode: "turtle";
        readonly codemirrorMimeType: "text/turtle";
        readonly languageId: 376;
    };
    readonly Twig: {
        readonly type: "markup";
        readonly color: "#c1d026";
        readonly extensions: [".twig"];
        readonly tmScope: "text.html.twig";
        readonly aceMode: "twig";
        readonly codemirrorMode: "twig";
        readonly codemirrorMimeType: "text/x-twig";
        readonly languageId: 377;
    };
    readonly 'Type Language': {
        readonly type: "data";
        readonly aliases: ["tl"];
        readonly extensions: [".tl"];
        readonly tmScope: "source.tl";
        readonly aceMode: "text";
        readonly languageId: 632765617;
    };
    readonly TypeScript: {
        readonly type: "programming";
        readonly color: "#2b7489";
        readonly aliases: ["ts"];
        readonly interpreters: ["deno", "ts-node"];
        readonly extensions: [".ts"];
        readonly tmScope: "source.ts";
        readonly aceMode: "typescript";
        readonly codemirrorMode: "javascript";
        readonly codemirrorMimeType: "application/typescript";
        readonly languageId: 378;
    };
    readonly 'Unified Parallel C': {
        readonly type: "programming";
        readonly color: "#4e3617";
        readonly group: "C";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly extensions: [".upc"];
        readonly tmScope: "source.c";
        readonly languageId: 379;
    };
    readonly 'Unity3D Asset': {
        readonly type: "data";
        readonly color: "#222c37";
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly extensions: [".anim", ".asset", ".mask", ".mat", ".meta", ".prefab", ".unity"];
        readonly tmScope: "source.yaml";
        readonly languageId: 380;
    };
    readonly 'Unix Assembly': {
        readonly type: "programming";
        readonly group: "Assembly";
        readonly extensions: [".s", ".ms"];
        readonly tmScope: "source.x86";
        readonly aceMode: "assembly_x86";
        readonly languageId: 120;
    };
    readonly Uno: {
        readonly type: "programming";
        readonly color: "#9933cc";
        readonly extensions: [".uno"];
        readonly aceMode: "csharp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csharp";
        readonly tmScope: "source.cs";
        readonly languageId: 381;
    };
    readonly UnrealScript: {
        readonly type: "programming";
        readonly color: "#a54c4d";
        readonly extensions: [".uc"];
        readonly tmScope: "source.java";
        readonly aceMode: "java";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-java";
        readonly languageId: 382;
    };
    readonly UrWeb: {
        readonly type: "programming";
        readonly color: "#ccccee";
        readonly aliases: ["Ur/Web", "Ur"];
        readonly extensions: [".ur", ".urs"];
        readonly tmScope: "source.ur";
        readonly aceMode: "text";
        readonly languageId: 383;
    };
    readonly V: {
        readonly type: "programming";
        readonly color: "#4f87c4";
        readonly aliases: ["vlang"];
        readonly extensions: [".v"];
        readonly tmScope: "source.v";
        readonly aceMode: "golang";
        readonly codemirrorMode: "go";
        readonly codemirrorMimeType: "text/x-go";
        readonly languageId: 603371597;
    };
    readonly VBA: {
        readonly type: "programming";
        readonly color: "#867db1";
        readonly extensions: [".bas", ".cls", ".frm", ".frx", ".vba"];
        readonly tmScope: "source.vbnet";
        readonly aliases: ["vb6", "visual basic 6", "visual basic for applications"];
        readonly aceMode: "text";
        readonly codemirrorMode: "vb";
        readonly codemirrorMimeType: "text/x-vb";
        readonly languageId: 399230729;
    };
    readonly VBScript: {
        readonly type: "programming";
        readonly color: "#15dcdc";
        readonly extensions: [".vbs"];
        readonly tmScope: "source.vbnet";
        readonly aceMode: "text";
        readonly codemirrorMode: "vbscript";
        readonly codemirrorMimeType: "text/vbscript";
        readonly languageId: 408016005;
    };
    readonly VCL: {
        readonly type: "programming";
        readonly color: "#148AA8";
        readonly extensions: [".vcl"];
        readonly tmScope: "source.varnish.vcl";
        readonly aceMode: "text";
        readonly languageId: 384;
    };
    readonly VHDL: {
        readonly type: "programming";
        readonly color: "#adb2cb";
        readonly extensions: [".vhdl", ".vhd", ".vhf", ".vhi", ".vho", ".vhs", ".vht", ".vhw"];
        readonly tmScope: "source.vhdl";
        readonly aceMode: "vhdl";
        readonly codemirrorMode: "vhdl";
        readonly codemirrorMimeType: "text/x-vhdl";
        readonly languageId: 385;
    };
    readonly Vala: {
        readonly type: "programming";
        readonly color: "#fbe5cd";
        readonly extensions: [".vala", ".vapi"];
        readonly tmScope: "source.vala";
        readonly aceMode: "vala";
        readonly languageId: 386;
    };
    readonly 'Valve Data Format': {
        readonly type: "data";
        readonly color: "#f26025";
        readonly aliases: ["keyvalues", "vdf"];
        readonly extensions: [".vdf"];
        readonly aceMode: "text";
        readonly tmScope: "source.keyvalues";
        readonly languageId: 544060961;
    };
    readonly Verilog: {
        readonly type: "programming";
        readonly color: "#b2b7f8";
        readonly extensions: [".v", ".veo"];
        readonly tmScope: "source.verilog";
        readonly aceMode: "verilog";
        readonly codemirrorMode: "verilog";
        readonly codemirrorMimeType: "text/x-verilog";
        readonly languageId: 387;
    };
    readonly 'Vim Help File': {
        readonly type: "prose";
        readonly color: "#199f4b";
        readonly aliases: ["help", "vimhelp"];
        readonly extensions: [".txt"];
        readonly tmScope: "text.vim-help";
        readonly aceMode: "text";
        readonly languageId: 508563686;
    };
    readonly 'Vim Script': {
        readonly type: "programming";
        readonly color: "#199f4b";
        readonly tmScope: "source.viml";
        readonly aliases: ["vim", "viml", "nvim"];
        readonly extensions: [".vim", ".vba", ".vmb"];
        readonly filenames: [".exrc", ".gvimrc", ".nvimrc", ".vimrc", "_vimrc", "gvimrc", "nvimrc", "vimrc"];
        readonly aceMode: "text";
        readonly languageId: 388;
    };
    readonly 'Vim Snippet': {
        readonly type: "markup";
        readonly color: "#199f4b";
        readonly aliases: ["SnipMate", "UltiSnip", "UltiSnips", "NeoSnippet"];
        readonly extensions: [".snip", ".snippet", ".snippets"];
        readonly tmScope: "source.vim-snippet";
        readonly aceMode: "text";
        readonly languageId: 81265970;
    };
    readonly 'Visual Basic .NET': {
        readonly type: "programming";
        readonly color: "#945db7";
        readonly extensions: [".vb", ".vbhtml"];
        readonly aliases: ["visual basic", "vbnet", "vb .net", "vb.net"];
        readonly tmScope: "source.vbnet";
        readonly aceMode: "text";
        readonly codemirrorMode: "vb";
        readonly codemirrorMimeType: "text/x-vb";
        readonly languageId: 389;
    };
    readonly Volt: {
        readonly type: "programming";
        readonly color: "#1F1F1F";
        readonly extensions: [".volt"];
        readonly tmScope: "source.d";
        readonly aceMode: "d";
        readonly codemirrorMode: "d";
        readonly codemirrorMimeType: "text/x-d";
        readonly languageId: 390;
    };
    readonly Vue: {
        readonly type: "markup";
        readonly color: "#41b883";
        readonly extensions: [".vue"];
        readonly tmScope: "text.html.vue";
        readonly aceMode: "html";
        readonly languageId: 391;
    };
    readonly 'Wavefront Material': {
        readonly type: "data";
        readonly extensions: [".mtl"];
        readonly tmScope: "source.wavefront.mtl";
        readonly aceMode: "text";
        readonly languageId: 392;
    };
    readonly 'Wavefront Object': {
        readonly type: "data";
        readonly extensions: [".obj"];
        readonly tmScope: "source.wavefront.obj";
        readonly aceMode: "text";
        readonly languageId: 393;
    };
    readonly 'Web Ontology Language': {
        readonly type: "data";
        readonly color: "#5b70bd";
        readonly extensions: [".owl"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly languageId: 394;
    };
    readonly WebAssembly: {
        readonly type: "programming";
        readonly color: "#04133b";
        readonly extensions: [".wast", ".wat"];
        readonly aliases: ["wast", "wasm"];
        readonly tmScope: "source.webassembly";
        readonly aceMode: "lisp";
        readonly codemirrorMode: "commonlisp";
        readonly codemirrorMimeType: "text/x-common-lisp";
        readonly languageId: 956556503;
    };
    readonly WebIDL: {
        readonly type: "programming";
        readonly extensions: [".webidl"];
        readonly tmScope: "source.webidl";
        readonly aceMode: "text";
        readonly codemirrorMode: "webidl";
        readonly codemirrorMimeType: "text/x-webidl";
        readonly languageId: 395;
    };
    readonly WebVTT: {
        readonly type: "data";
        readonly wrap: true;
        readonly extensions: [".vtt"];
        readonly tmScope: "source.vtt";
        readonly aceMode: "text";
        readonly languageId: 658679714;
    };
    readonly 'Wget Config': {
        readonly type: "data";
        readonly group: "INI";
        readonly aliases: ["wgetrc"];
        readonly filenames: [".wgetrc"];
        readonly tmScope: "source.wgetrc";
        readonly aceMode: "text";
        readonly languageId: 668457123;
    };
    readonly Wikitext: {
        readonly type: "prose";
        readonly color: "#fc5757";
        readonly wrap: true;
        readonly aliases: ["mediawiki", "wiki"];
        readonly extensions: [".mediawiki", ".wiki", ".wikitext"];
        readonly tmScope: "text.html.mediawiki";
        readonly aceMode: "text";
        readonly languageId: 228;
    };
    readonly 'Windows Registry Entries': {
        readonly type: "data";
        readonly color: "#52d5ff";
        readonly extensions: [".reg"];
        readonly tmScope: "source.reg";
        readonly aceMode: "ini";
        readonly codemirrorMode: "properties";
        readonly codemirrorMimeType: "text/x-properties";
        readonly languageId: 969674868;
    };
    readonly Wollok: {
        readonly type: "programming";
        readonly color: "#a23738";
        readonly extensions: [".wlk"];
        readonly aceMode: "text";
        readonly tmScope: "source.wollok";
        readonly languageId: 632745969;
    };
    readonly 'World of Warcraft Addon Data': {
        readonly type: "data";
        readonly color: "#f7e43f";
        readonly extensions: [".toc"];
        readonly tmScope: "source.toc";
        readonly aceMode: "text";
        readonly languageId: 396;
    };
    readonly 'X BitMap': {
        readonly type: "data";
        readonly group: "C";
        readonly aliases: ["xbm"];
        readonly extensions: [".xbm"];
        readonly aceMode: "c_cpp";
        readonly tmScope: "source.c";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 782911107;
    };
    readonly 'X Font Directory Index': {
        readonly type: "data";
        readonly filenames: ["encodings.dir", "fonts.alias", "fonts.dir", "fonts.scale"];
        readonly tmScope: "source.fontdir";
        readonly aceMode: "text";
        readonly languageId: 208700028;
    };
    readonly 'X PixMap': {
        readonly type: "data";
        readonly group: "C";
        readonly aliases: ["xpm"];
        readonly extensions: [".xpm", ".pm"];
        readonly aceMode: "c_cpp";
        readonly tmScope: "source.c";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 781846279;
    };
    readonly X10: {
        readonly type: "programming";
        readonly aliases: ["xten"];
        readonly aceMode: "text";
        readonly extensions: [".x10"];
        readonly color: "#4B6BEF";
        readonly tmScope: "source.x10";
        readonly languageId: 397;
    };
    readonly XC: {
        readonly type: "programming";
        readonly color: "#99DA07";
        readonly extensions: [".xc"];
        readonly tmScope: "source.xc";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 398;
    };
    readonly XCompose: {
        readonly type: "data";
        readonly filenames: [".XCompose", "XCompose", "xcompose"];
        readonly tmScope: "config.xcompose";
        readonly aceMode: "text";
        readonly languageId: 225167241;
    };
    readonly XML: {
        readonly type: "data";
        readonly color: "#0060ac";
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly aliases: ["rss", "xsd", "wsdl"];
        readonly extensions: [".xml", ".adml", ".admx", ".ant", ".axml", ".builds", ".ccproj", ".ccxml", ".clixml", ".cproject", ".cscfg", ".csdef", ".csl", ".csproj", ".ct", ".depproj", ".dita", ".ditamap", ".ditaval", ".dll.config", ".dotsettings", ".filters", ".fsproj", ".fxml", ".glade", ".gml", ".gmx", ".grxml", ".gst", ".iml", ".ivy", ".jelly", ".jsproj", ".kml", ".launch", ".mdpolicy", ".mjml", ".mm", ".mod", ".mxml", ".natvis", ".ncl", ".ndproj", ".nproj", ".nuspec", ".odd", ".osm", ".pkgproj", ".pluginspec", ".proj", ".props", ".ps1xml", ".psc1", ".pt", ".rdf", ".res", ".resx", ".rs", ".rss", ".sch", ".scxml", ".sfproj", ".shproj", ".srdf", ".storyboard", ".sublime-snippet", ".targets", ".tml", ".ts", ".tsx", ".ui", ".urdf", ".ux", ".vbproj", ".vcxproj", ".vsixmanifest", ".vssettings", ".vstemplate", ".vxml", ".wixproj", ".workflow", ".wsdl", ".wsf", ".wxi", ".wxl", ".wxs", ".x3d", ".xacro", ".xaml", ".xib", ".xlf", ".xliff", ".xmi", ".xml.dist", ".xmp", ".xproj", ".xsd", ".xspec", ".xul", ".zcml"];
        readonly filenames: [".classpath", ".cproject", ".project", "App.config", "NuGet.config", "Settings.StyleCop", "Web.Debug.config", "Web.Release.config", "Web.config", "packages.config"];
        readonly languageId: 399;
    };
    readonly 'XML Property List': {
        readonly type: "data";
        readonly color: "#0060ac";
        readonly group: "XML";
        readonly extensions: [".plist", ".stTheme", ".tmCommand", ".tmLanguage", ".tmPreferences", ".tmSnippet", ".tmTheme"];
        readonly tmScope: "text.xml.plist";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 75622871;
    };
    readonly XPages: {
        readonly type: "data";
        readonly extensions: [".xsp-config", ".xsp.metadata"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 400;
    };
    readonly XProc: {
        readonly type: "programming";
        readonly extensions: [".xpl", ".xproc"];
        readonly tmScope: "text.xml";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly languageId: 401;
    };
    readonly XQuery: {
        readonly type: "programming";
        readonly color: "#5232e7";
        readonly extensions: [".xquery", ".xq", ".xql", ".xqm", ".xqy"];
        readonly aceMode: "xquery";
        readonly codemirrorMode: "xquery";
        readonly codemirrorMimeType: "application/xquery";
        readonly tmScope: "source.xq";
        readonly languageId: 402;
    };
    readonly XS: {
        readonly type: "programming";
        readonly extensions: [".xs"];
        readonly tmScope: "source.c";
        readonly aceMode: "c_cpp";
        readonly codemirrorMode: "clike";
        readonly codemirrorMimeType: "text/x-csrc";
        readonly languageId: 403;
    };
    readonly XSLT: {
        readonly type: "programming";
        readonly aliases: ["xsl"];
        readonly extensions: [".xslt", ".xsl"];
        readonly tmScope: "text.xml.xsl";
        readonly aceMode: "xml";
        readonly codemirrorMode: "xml";
        readonly codemirrorMimeType: "text/xml";
        readonly color: "#EB8CEB";
        readonly languageId: 404;
    };
    readonly Xojo: {
        readonly type: "programming";
        readonly color: "#81bd41";
        readonly extensions: [".xojo_code", ".xojo_menu", ".xojo_report", ".xojo_script", ".xojo_toolbar", ".xojo_window"];
        readonly tmScope: "source.xojo";
        readonly aceMode: "text";
        readonly languageId: 405;
    };
    readonly Xonsh: {
        readonly type: "programming";
        readonly color: "#285EEF";
        readonly extensions: [".xsh"];
        readonly tmScope: "source.python";
        readonly aceMode: "text";
        readonly codemirrorMode: "python";
        readonly codemirrorMimeType: "text/x-python";
        readonly languageId: 614078284;
    };
    readonly Xtend: {
        readonly type: "programming";
        readonly color: "#24255d";
        readonly extensions: [".xtend"];
        readonly tmScope: "source.xtend";
        readonly aceMode: "text";
        readonly languageId: 406;
    };
    readonly YAML: {
        readonly type: "data";
        readonly color: "#cb171e";
        readonly tmScope: "source.yaml";
        readonly aliases: ["yml"];
        readonly extensions: [".yml", ".mir", ".reek", ".rviz", ".sublime-syntax", ".syntax", ".yaml", ".yaml-tmlanguage", ".yaml.sed", ".yml.mysql"];
        readonly filenames: [".clang-format", ".clang-tidy", ".gemrc", "glide.lock", "yarn.lock"];
        readonly aceMode: "yaml";
        readonly codemirrorMode: "yaml";
        readonly codemirrorMimeType: "text/x-yaml";
        readonly languageId: 407;
    };
    readonly YANG: {
        readonly type: "data";
        readonly extensions: [".yang"];
        readonly tmScope: "source.yang";
        readonly aceMode: "text";
        readonly languageId: 408;
    };
    readonly YARA: {
        readonly type: "programming";
        readonly color: "#220000";
        readonly aceMode: "text";
        readonly extensions: [".yar", ".yara"];
        readonly tmScope: "source.yara";
        readonly languageId: 805122868;
    };
    readonly YASnippet: {
        readonly type: "markup";
        readonly aliases: ["snippet", "yas"];
        readonly color: "#32AB90";
        readonly extensions: [".yasnippet"];
        readonly tmScope: "source.yasnippet";
        readonly aceMode: "text";
        readonly languageId: 378760102;
    };
    readonly Yacc: {
        readonly type: "programming";
        readonly extensions: [".y", ".yacc", ".yy"];
        readonly tmScope: "source.yacc";
        readonly aceMode: "text";
        readonly color: "#4B6C4B";
        readonly languageId: 409;
    };
    readonly ZAP: {
        readonly type: "programming";
        readonly color: "#0d665e";
        readonly extensions: [".zap", ".xzap"];
        readonly tmScope: "source.zap";
        readonly aceMode: "text";
        readonly languageId: 952972794;
    };
    readonly ZIL: {
        readonly type: "programming";
        readonly color: "#dc75e5";
        readonly extensions: [".zil", ".mud"];
        readonly tmScope: "source.zil";
        readonly aceMode: "text";
        readonly languageId: 973483626;
    };
    readonly Zeek: {
        readonly type: "programming";
        readonly aliases: ["bro"];
        readonly extensions: [".zeek", ".bro"];
        readonly tmScope: "source.zeek";
        readonly aceMode: "text";
        readonly languageId: 40;
    };
    readonly ZenScript: {
        readonly type: "programming";
        readonly color: "#00BCD1";
        readonly extensions: [".zs"];
        readonly tmScope: "source.zenscript";
        readonly aceMode: "text";
        readonly languageId: 494938890;
    };
    readonly Zephir: {
        readonly type: "programming";
        readonly color: "#118f9e";
        readonly extensions: [".zep"];
        readonly tmScope: "source.php.zephir";
        readonly aceMode: "php";
        readonly languageId: 410;
    };
    readonly Zig: {
        readonly type: "programming";
        readonly color: "#ec915c";
        readonly extensions: [".zig"];
        readonly tmScope: "source.zig";
        readonly aceMode: "text";
        readonly languageId: 646424281;
    };
    readonly Zimpl: {
        readonly type: "programming";
        readonly color: "#d67711";
        readonly extensions: [".zimpl", ".zmpl", ".zpl"];
        readonly tmScope: "none";
        readonly aceMode: "text";
        readonly languageId: 411;
    };
    readonly 'cURL Config': {
        readonly type: "data";
        readonly group: "INI";
        readonly aliases: ["curlrc"];
        readonly filenames: [".curlrc", "_curlrc"];
        readonly tmScope: "source.curlrc";
        readonly aceMode: "text";
        readonly languageId: 992375436;
    };
    readonly desktop: {
        readonly type: "data";
        readonly extensions: [".desktop", ".desktop.in"];
        readonly tmScope: "source.desktop";
        readonly aceMode: "text";
        readonly languageId: 412;
    };
    readonly dircolors: {
        readonly type: "data";
        readonly extensions: [".dircolors"];
        readonly filenames: [".dir_colors", ".dircolors", "DIR_COLORS", "_dir_colors", "_dircolors", "dir_colors"];
        readonly tmScope: "source.dircolors";
        readonly aceMode: "text";
        readonly languageId: 691605112;
    };
    readonly eC: {
        readonly type: "programming";
        readonly color: "#913960";
        readonly extensions: [".ec", ".eh"];
        readonly tmScope: "source.c.ec";
        readonly aceMode: "text";
        readonly languageId: 413;
    };
    readonly edn: {
        readonly type: "data";
        readonly aceMode: "clojure";
        readonly codemirrorMode: "clojure";
        readonly codemirrorMimeType: "text/x-clojure";
        readonly extensions: [".edn"];
        readonly tmScope: "source.clojure";
        readonly languageId: 414;
    };
    readonly fish: {
        readonly type: "programming";
        readonly color: "#4aae47";
        readonly group: "Shell";
        readonly interpreters: ["fish"];
        readonly extensions: [".fish"];
        readonly tmScope: "source.fish";
        readonly aceMode: "text";
        readonly languageId: 415;
    };
    readonly jq: {
        readonly color: "#c7254e";
        readonly aceMode: "text";
        readonly type: "programming";
        readonly extensions: [".jq"];
        readonly tmScope: "source.jq";
        readonly languageId: 905371884;
    };
    readonly 'mIRC Script': {
        readonly type: "programming";
        readonly color: "#3d57c3";
        readonly extensions: [".mrc"];
        readonly tmScope: "source.msl";
        readonly aceMode: "text";
        readonly languageId: 517654727;
    };
    readonly mcfunction: {
        readonly type: "programming";
        readonly color: "#E22837";
        readonly extensions: [".mcfunction"];
        readonly tmScope: "source.mcfunction";
        readonly aceMode: "text";
        readonly languageId: 462488745;
    };
    readonly mupad: {
        readonly type: "programming";
        readonly color: "#244963";
        readonly extensions: [".mu"];
        readonly tmScope: "source.mupad";
        readonly aceMode: "text";
        readonly languageId: 416;
    };
    readonly nanorc: {
        readonly type: "data";
        readonly color: "#2d004d";
        readonly group: "INI";
        readonly extensions: [".nanorc"];
        readonly filenames: [".nanorc", "nanorc"];
        readonly tmScope: "source.nanorc";
        readonly aceMode: "text";
        readonly languageId: 775996197;
    };
    readonly nesC: {
        readonly type: "programming";
        readonly color: "#94B0C7";
        readonly extensions: [".nc"];
        readonly aceMode: "text";
        readonly tmScope: "source.nesc";
        readonly languageId: 417;
    };
    readonly ooc: {
        readonly type: "programming";
        readonly color: "#b0b77e";
        readonly extensions: [".ooc"];
        readonly tmScope: "source.ooc";
        readonly aceMode: "text";
        readonly languageId: 418;
    };
    readonly q: {
        readonly type: "programming";
        readonly extensions: [".q"];
        readonly tmScope: "source.q";
        readonly aceMode: "text";
        readonly color: "#0040cd";
        readonly languageId: 970539067;
    };
    readonly reStructuredText: {
        readonly type: "prose";
        readonly color: "#141414";
        readonly wrap: true;
        readonly aliases: ["rst"];
        readonly extensions: [".rst", ".rest", ".rest.txt", ".rst.txt"];
        readonly tmScope: "text.restructuredtext";
        readonly aceMode: "text";
        readonly codemirrorMode: "rst";
        readonly codemirrorMimeType: "text/x-rst";
        readonly languageId: 419;
    };
    readonly 'robots.txt': {
        readonly type: "data";
        readonly aliases: ["robots", "robots txt"];
        readonly filenames: ["robots.txt"];
        readonly aceMode: "text";
        readonly tmScope: "text.robots-txt";
        readonly languageId: 674736065;
    };
    readonly sed: {
        readonly type: "programming";
        readonly color: "#64b970";
        readonly extensions: [".sed"];
        readonly interpreters: ["gsed", "minised", "sed", "ssed"];
        readonly aceMode: "text";
        readonly tmScope: "source.sed";
        readonly languageId: 847830017;
    };
    readonly wdl: {
        readonly type: "programming";
        readonly color: "#42f1f4";
        readonly extensions: [".wdl"];
        readonly tmScope: "source.wdl";
        readonly aceMode: "text";
        readonly languageId: 374521672;
    };
    readonly wisp: {
        readonly type: "programming";
        readonly aceMode: "clojure";
        readonly codemirrorMode: "clojure";
        readonly codemirrorMimeType: "text/x-clojure";
        readonly color: "#7582D1";
        readonly extensions: [".wisp"];
        readonly tmScope: "source.clojure";
        readonly languageId: 420;
    };
    readonly xBase: {
        readonly type: "programming";
        readonly color: "#403a40";
        readonly aliases: ["advpl", "clipper", "foxpro"];
        readonly extensions: [".prg", ".ch", ".prw"];
        readonly tmScope: "source.harbour";
        readonly aceMode: "text";
        readonly languageId: 421;
    };
};
export type LanguageName = keyof typeof languageMap;
